/* SETTING 1 */

ods graphics off;
ods html close;
ods listing;

DATA TEST;
INPUT Subject COUNT;
CARDS;
1 1000
;RUN;

DATA TEST (DROP=subject count);
	SET TEST;
	DO i=1 TO COUNT;
	OUTPUT;
	END;
RUN;

data test (DROP=i);
set test;
Subject = i;
run;

data test;
set test;
if Subject =< 750  then treatment = 1;
else treatment = 0;
run;


%MACRO trial(NUMSAMP=, INDSET=, HR=, OUTDSET=);
	%LET BEGINTIME=%SYSFUNC(TIME());
	DM LOG 'CLEAR';

	PROC DATASETS LIBRARY=WORK;
		DELETE &OUTDSET;
    options nosource nonotes;
	RUN;QUIT;
	PROC DATASETS LIBRARY=WORK;
		DELETE OPUT;
    options nosource nonotes;
	RUN;QUIT;

	ODS LISTING CLOSE;

	%DO i = 1 %TO &NUMSAMP;
data realization&i;
set &indset;
if treatment = 1 then covariate = ranbin(&i,1,0.3);
else covariate = ranbin(&i+10000,1,0.3);

if treatment = 1 AND covariate = 1
then X = ranexp(&i+20000)/(0.12*&HR);
else if treatment = 0 AND covariate = 1
then X = ranexp(&i+30000)/0.12;
else if treatment = 1 AND covariate = 0
then X = ranexp(&i+40000)/(0.06*&HR);
else X = ranexp(&i+50000)/0.06;

C = uniform(&i+60000)*2 + 3;
if treatment = 1 then H = ranexp(&i+70000)/0.05;
else H = ranexp(&i+80000)/0.05;
if X < C AND X < H then Y = 1;
else Y = 0;
T = min(X,C,H);
if H < C AND H < X then Z = 1;
else Z = 0;
if Y = 0 AND Z = 0 then S = 1;
else S = 0;
treat_b = 0.405;
covar_b = 0.693;
w = EXP(treatment*treat_b + covariate*covar_b);
options nosource nonotes;
run;

ods output ParameterEstimates = Oput_Cox&i;
proc phreg data=realization&i;
model T*Y(0)=treatment covariate / risklimits;
options nosource nonotes;
run;

ods output Summary=treatment_count&i;
proc means data=realization&i sum;
var Y Z S T;
where treatment=1;
options nosource nonotes;
run;

data treatment_count&i (drop = Y_sum Z_sum S_sum T_sum);
set treatment_count&i;
treatment_count = Y_sum;
treatment_competing = Z_sum;
treatment_non_event = S_sum;
treatment_time = T_sum;
options nosource nonotes;
run;

ods output Summary=control_count&i;
proc means data=realization&i sum;
var Y Z T S;
where treatment=0;
options nosource nonotes;
run;

data control_count&i (drop = Y_sum Z_sum S_sum T_sum);
set control_count&i;
control_count = Y_sum;
control_competing = Z_sum;
control_non_event = S_sum;
control_time = T_sum;
options nosource nonotes;
run;

ods output PearsonCorr=Corr&i;
proc corr data=realization&i;
var treatment covariate;
weight w;
run;

data corr&i;
set corr&i;
if Variable = 'covariate' then delete;
run;

ods output Summary=treatment_prev&i;
proc means data=realization&i mean;
var treatment;
options nosource nonotes;
run;

data Oput&i;
merge Oput_Cox&i treatment_count&i control_count&i corr&i
treatment_prev&i;
run;

		PROC APPEND BASE=&OUTDSET NEW=OPUT&i FORCE;
		RUN;

		PROC DATASETS LIBRARY=WORK;
			DELETE OPUT&i SAMP&i Oput_Cox&i treatment_count&i control_count&i corr&i
            treatment_prev&i realization&i;
		RUN;QUIT;

%END;
	ODS LISTING;


	%LET ENDTIME=%SYSFUNC(TIME());
	%LET TOTALTIME=%SYSFUNC(ROUND(%SYSEVALF(&ENDTIME-&BEGINTIME),.01));


	%LET ENDTIME=%SYSFUNC(TIME());
	%LET TOTALTIME=%SYSFUNC(ROUND(%SYSEVALF(&ENDTIME-&BEGINTIME),.01));
	%PUT TOTAL TIME FOR MACRO TO RUN (SECONDS) = &TOTALTIME;

%MEND trial;

%trial(NUMSAMP=2000, INDSET=test, HR=1.5, OUTDSET=DONE);

data done;
set done;
if Parameter = 'covariate' then delete;
R_squared = covariate*covariate;
if HRLowerCL < 1.5 < HRUpperCL then coverage = 1;
else coverage = 0;
if HRLowerCL > 1 then prob_lcl_above_1 = 1;
else prob_lcl_above_1  = 0;
run;

ods output Summary=Final;
proc means data=done n mean std nolabels median;
var treatment_count treatment_competing treatment_non_event treatment_time
control_count control_competing control_non_event control_time
R_squared 
Estimate HazardRatio HRLowerCL HRUpperCL coverage StdErr 
prob_lcl_above_1
treatment_Mean;
options nosource nonotes;
run;

data final1;
set final;
little_r = (treatment_Mean_Mean)/(1-treatment_Mean_Mean);
total_events = treatment_count_Mean + control_count_Mean;
crude_RR = (treatment_count_Mean / treatment_time_Mean)/(control_count_Mean/control_time_mean);
little_r_prime = treatment_non_event_Mean / control_non_event_Mean;
little_r_tilde = (little_r + little_r_prime)/2;

SE0 = (SQRT(((little_r + 1)**2)/(total_events*little_r)))/StdErr_Mean;
SE0_adj = (SQRT(((little_r + 1)**2)/(total_events*little_r))/SQRT(1-R_squared_Mean))/StdErr_Mean;

SE1 = (SQRT(((little_r*crude_RR + 1)**2)/(total_events*little_r*crude_RR)))/StdErr_Mean;
SE1_adj = (SQRT(((little_r*crude_RR + 1)**2)/(total_events*little_r*crude_RR))/SQRT(1-R_squared_Mean))/StdErr_Mean;

SE2 = (SQRT(((little_r_tilde*crude_RR + 1)**2)/(total_events*little_r_tilde*crude_RR)))/StdErr_Mean;
SE2_adj = (SQRT(((little_r_tilde*crude_RR + 1)**2)/(total_events*little_r_tilde*crude_RR))/SQRT(1-R_squared_Mean))/StdErr_Mean;

SE3 = (SQRT(1/treatment_count_Mean + 1/control_count_Mean))/StdErr_Mean;
SE3_adj = SQRT((1/treatment_count_Mean + 1/control_count_Mean)/(1-R_squared_Mean))/StdErr_Mean;


SE0_adj_LCL = EXP(Estimate_Mean - 1.96*(SQRT(((little_r + 1)**2)/(total_events*little_r))/SQRT(1-R_squared_Mean)));
SE1_adj_LCL = EXP(Estimate_Mean - 1.96*(SQRT(((little_r*crude_RR + 1)**2)/(total_events*little_r*crude_RR))/SQRT(1-R_squared_Mean)));
SE2_adj_LCL = EXP(Estimate_Mean - 1.96*(SQRT(((little_r_tilde*crude_RR + 1)**2)/(total_events*little_r_tilde*crude_RR))/SQRT(1-R_squared_Mean)));
SE3_adj_LCL = EXP(Estimate_Mean - 1.96*SQRT((1/treatment_count_Mean + 1/control_count_Mean)/(1-R_squared_Mean)));
LCL_sim = HRLowerCL_Mean;

SE0_adj_UCL = EXP(Estimate_Mean + 1.96*(SQRT(((little_r + 1)**2)/(total_events*little_r))/SQRT(1-R_squared_Mean)));
SE1_adj_UCL = EXP(Estimate_Mean + 1.96*(SQRT(((little_r*crude_RR + 1)**2)/(total_events*little_r*crude_RR))/SQRT(1-R_squared_Mean)));
SE2_adj_UCL = EXP(Estimate_Mean + 1.96*(SQRT(((little_r_tilde*crude_RR + 1)**2)/(total_events*little_r_tilde*crude_RR))/SQRT(1-R_squared_Mean)));
SE3_adj_UCL = EXP(Estimate_Mean + 1.96*SQRT((1/treatment_count_Mean + 1/control_count_Mean)/(1-R_squared_Mean)));
UCL_sim = HRUpperCL_Mean;

if Estimate_Mean > 0 then
SE0_adj_power=1-cdf('NORMAL',0,LOG(1.5)-1.96*(SQRT(((little_r + 1)**2)/(total_events*little_r))/SQRT(1-R_squared_Mean)),(SQRT(((little_r + 1)**2)/(total_events*little_r))/SQRT(1-R_squared_Mean)));
else SE0_adj_power=cdf('NORMAL',0,LOG(1.5)+1.96*(SQRT(((little_r + 1)**2)/(total_events*little_r))/SQRT(1-R_squared_Mean)),(SQRT(((little_r + 1)**2)/(total_events*little_r))/SQRT(1-R_squared_Mean)));

if Estimate_Mean > 0 then
SE1_adj_power=1-cdf('NORMAL',0,LOG(1.5)-1.96*(SQRT(((little_r*crude_RR + 1)**2)/(total_events*little_r*crude_RR))/SQRT(1-R_squared_Mean)),(SQRT(((little_r*crude_RR + 1)**2)/(total_events*little_r*crude_RR))/SQRT(1-R_squared_Mean)));
else SE1_adj_power=cdf('NORMAL',0,LOG(1.5)+1.96*(SQRT(((little_r*crude_RR + 1)**2)/(total_events*little_r*crude_RR))/SQRT(1-R_squared_Mean)),(SQRT(((little_r*crude_RR + 1)**2)/(total_events*little_r*crude_RR))/SQRT(1-R_squared_Mean)));

if Estimate_Mean > 0 then
SE2_adj_power=1-cdf('NORMAL',0,LOG(1.5)-1.96*(SQRT(((little_r_tilde*crude_RR + 1)**2)/(total_events*little_r_tilde*crude_RR))/SQRT(1-R_squared_Mean)),(SQRT(((little_r_tilde*crude_RR + 1)**2)/(total_events*little_r_tilde*crude_RR))/SQRT(1-R_squared_Mean)));
else SE2_adj_power=cdf('NORMAL',0,LOG(1.5)+1.96*(SQRT(((little_r_tilde*crude_RR + 1)**2)/(total_events*little_r_tilde*crude_RR))/SQRT(1-R_squared_Mean)),(SQRT(((little_r_tilde*crude_RR + 1)**2)/(total_events*little_r_tilde*crude_RR))/SQRT(1-R_squared_Mean)));

if Estimate_Mean > 0 then
SE3_adj_power=1-cdf('NORMAL',0,LOG(1.5)-1.96*(SQRT((1/treatment_count_Mean + 1/control_count_Mean)/(1-R_squared_Mean))),SQRT((1/treatment_count_Mean + 1/control_count_Mean)/(1-R_squared_Mean)));
else SE3_adj_power=cdf('NORMAL',0,LOG(1.5)+1.96*(SQRT((1/treatment_count_Mean + 1/control_count_Mean)/(1-R_squared_Mean))),SQRT((1/treatment_count_Mean + 1/control_count_Mean)/(1-R_squared_Mean)));

power_sim = prob_lcl_above_1_Mean;
SE_margin = StdErr_StdDev / SQRT(StdErr_N);
Power_margin = SQRT(power_sim*(1-power_sim)/StdErr_N);
options nosource nonotes;
run;

/* SETTING 2 */

ods graphics off;
ods html close;
ods listing;

DATA TEST;
INPUT Subject COUNT;
CARDS;
1 1000
;RUN;

DATA TEST (DROP=subject count);
	SET TEST;
	DO i=1 TO COUNT;
	OUTPUT;
	END;
RUN;

data test (DROP=i);
set test;
Subject = i;
run;

data test;
set test;
if Subject =< 750  then treatment = 1;
else treatment = 0;
run;


%MACRO trial(NUMSAMP=, INDSET=, HR=, OUTDSET=);
	%LET BEGINTIME=%SYSFUNC(TIME());
	DM LOG 'CLEAR';

	PROC DATASETS LIBRARY=WORK;
		DELETE &OUTDSET;
    options nosource nonotes;
	RUN;QUIT;
	PROC DATASETS LIBRARY=WORK;
		DELETE OPUT;
    options nosource nonotes;
	RUN;QUIT;

	ODS LISTING CLOSE;

	%DO i = 1 %TO &NUMSAMP;
data realization&i;
set &indset;
if treatment = 1 then covariate = ranbin(&i,1,0.6);
else covariate = ranbin(&i+10000,1,0.3);

if treatment = 1 AND covariate = 1
then X = ranexp(&i+20000)/(0.12*&HR);
else if treatment = 0 AND covariate = 1
then X = ranexp(&i+30000)/0.12;
else if treatment = 1 AND covariate = 0
then X = ranexp(&i+40000)/(0.06*&HR);
else X = ranexp(&i+50000)/0.06;

C = uniform(&i+60000)*2 + 3;
if treatment = 1 then H = ranexp(&i+70000)/0.05;
else H = ranexp(&i+80000)/0.05;
if X < C AND X < H then Y = 1;
else Y = 0;
T = min(X,C,H);
if H < C AND H < X then Z = 1;
else Z = 0;
if Y = 0 AND Z = 0 then S = 1;
else S = 0;
treat_b = 0.405;
covar_b = 0.693;
w = EXP(treatment*treat_b + covariate*covar_b);
options nosource nonotes;
run;

ods output ParameterEstimates = Oput_Cox&i;
proc phreg data=realization&i;
model T*Y(0)=treatment covariate / risklimits;
options nosource nonotes;
run;

ods output Summary=treatment_count&i;
proc means data=realization&i sum;
var Y Z S T;
where treatment=1;
options nosource nonotes;
run;

data treatment_count&i (drop = Y_sum Z_sum S_sum T_sum);
set treatment_count&i;
treatment_count = Y_sum;
treatment_competing = Z_sum;
treatment_non_event = S_sum;
treatment_time = T_sum;
options nosource nonotes;
run;

ods output Summary=control_count&i;
proc means data=realization&i sum;
var Y Z T S;
where treatment=0;
options nosource nonotes;
run;

data control_count&i (drop = Y_sum Z_sum S_sum T_sum);
set control_count&i;
control_count = Y_sum;
control_competing = Z_sum;
control_non_event = S_sum;
control_time = T_sum;
options nosource nonotes;
run;

ods output PearsonCorr=Corr&i;
proc corr data=realization&i;
var treatment covariate;
weight w;
run;

data corr&i;
set corr&i;
if Variable = 'covariate' then delete;
run;

ods output Summary=treatment_prev&i;
proc means data=realization&i mean;
var treatment;
options nosource nonotes;
run;

data Oput&i;
merge Oput_Cox&i treatment_count&i control_count&i corr&i
treatment_prev&i;
run;

		PROC APPEND BASE=&OUTDSET NEW=OPUT&i FORCE;
		RUN;

		PROC DATASETS LIBRARY=WORK;
			DELETE OPUT&i SAMP&i Oput_Cox&i treatment_count&i control_count&i corr&i
            treatment_prev&i realization&i;
		RUN;QUIT;

%END;
	ODS LISTING;


	%LET ENDTIME=%SYSFUNC(TIME());
	%LET TOTALTIME=%SYSFUNC(ROUND(%SYSEVALF(&ENDTIME-&BEGINTIME),.01));


	%LET ENDTIME=%SYSFUNC(TIME());
	%LET TOTALTIME=%SYSFUNC(ROUND(%SYSEVALF(&ENDTIME-&BEGINTIME),.01));
	%PUT TOTAL TIME FOR MACRO TO RUN (SECONDS) = &TOTALTIME;

%MEND trial;

%trial(NUMSAMP=2000, INDSET=test, HR=1.5, OUTDSET=DONE);

data done;
set done;
if Parameter = 'covariate' then delete;
R_squared = covariate*covariate;
if HRLowerCL < 1.5 < HRUpperCL then coverage = 1;
else coverage = 0;
if HRLowerCL > 1 then prob_lcl_above_1 = 1;
else prob_lcl_above_1  = 0;
run;

ods output Summary=Final;
proc means data=done n mean std nolabels median;
var treatment_count treatment_competing treatment_non_event treatment_time
control_count control_competing control_non_event control_time
R_squared 
Estimate HazardRatio HRLowerCL HRUpperCL coverage StdErr 
prob_lcl_above_1
treatment_Mean;
options nosource nonotes;
run;

data final2;
set final;
little_r = (treatment_Mean_Mean)/(1-treatment_Mean_Mean);
total_events = treatment_count_Mean + control_count_Mean;
crude_RR = (treatment_count_Mean / treatment_time_Mean)/(control_count_Mean/control_time_mean);
little_r_prime = treatment_non_event_Mean / control_non_event_Mean;
little_r_tilde = (little_r + little_r_prime)/2;

SE0 = (SQRT(((little_r + 1)**2)/(total_events*little_r)))/StdErr_Mean;
SE0_adj = (SQRT(((little_r + 1)**2)/(total_events*little_r))/SQRT(1-R_squared_Mean))/StdErr_Mean;

SE1 = (SQRT(((little_r*crude_RR + 1)**2)/(total_events*little_r*crude_RR)))/StdErr_Mean;
SE1_adj = (SQRT(((little_r*crude_RR + 1)**2)/(total_events*little_r*crude_RR))/SQRT(1-R_squared_Mean))/StdErr_Mean;

SE2 = (SQRT(((little_r_tilde*crude_RR + 1)**2)/(total_events*little_r_tilde*crude_RR)))/StdErr_Mean;
SE2_adj = (SQRT(((little_r_tilde*crude_RR + 1)**2)/(total_events*little_r_tilde*crude_RR))/SQRT(1-R_squared_Mean))/StdErr_Mean;

SE3 = (SQRT(1/treatment_count_Mean + 1/control_count_Mean))/StdErr_Mean;
SE3_adj = SQRT((1/treatment_count_Mean + 1/control_count_Mean)/(1-R_squared_Mean))/StdErr_Mean;


SE0_adj_LCL = EXP(Estimate_Mean - 1.96*(SQRT(((little_r + 1)**2)/(total_events*little_r))/SQRT(1-R_squared_Mean)));
SE1_adj_LCL = EXP(Estimate_Mean - 1.96*(SQRT(((little_r*crude_RR + 1)**2)/(total_events*little_r*crude_RR))/SQRT(1-R_squared_Mean)));
SE2_adj_LCL = EXP(Estimate_Mean - 1.96*(SQRT(((little_r_tilde*crude_RR + 1)**2)/(total_events*little_r_tilde*crude_RR))/SQRT(1-R_squared_Mean)));
SE3_adj_LCL = EXP(Estimate_Mean - 1.96*SQRT((1/treatment_count_Mean + 1/control_count_Mean)/(1-R_squared_Mean)));
LCL_sim = HRLowerCL_Mean;

SE0_adj_UCL = EXP(Estimate_Mean + 1.96*(SQRT(((little_r + 1)**2)/(total_events*little_r))/SQRT(1-R_squared_Mean)));
SE1_adj_UCL = EXP(Estimate_Mean + 1.96*(SQRT(((little_r*crude_RR + 1)**2)/(total_events*little_r*crude_RR))/SQRT(1-R_squared_Mean)));
SE2_adj_UCL = EXP(Estimate_Mean + 1.96*(SQRT(((little_r_tilde*crude_RR + 1)**2)/(total_events*little_r_tilde*crude_RR))/SQRT(1-R_squared_Mean)));
SE3_adj_UCL = EXP(Estimate_Mean + 1.96*SQRT((1/treatment_count_Mean + 1/control_count_Mean)/(1-R_squared_Mean)));
UCL_sim = HRUpperCL_Mean;

if Estimate_Mean > 0 then
SE0_adj_power=1-cdf('NORMAL',0,LOG(1.5)-1.96*(SQRT(((little_r + 1)**2)/(total_events*little_r))/SQRT(1-R_squared_Mean)),(SQRT(((little_r + 1)**2)/(total_events*little_r))/SQRT(1-R_squared_Mean)));
else SE0_adj_power=cdf('NORMAL',0,LOG(1.5)+1.96*(SQRT(((little_r + 1)**2)/(total_events*little_r))/SQRT(1-R_squared_Mean)),(SQRT(((little_r + 1)**2)/(total_events*little_r))/SQRT(1-R_squared_Mean)));

if Estimate_Mean > 0 then
SE1_adj_power=1-cdf('NORMAL',0,LOG(1.5)-1.96*(SQRT(((little_r*crude_RR + 1)**2)/(total_events*little_r*crude_RR))/SQRT(1-R_squared_Mean)),(SQRT(((little_r*crude_RR + 1)**2)/(total_events*little_r*crude_RR))/SQRT(1-R_squared_Mean)));
else SE1_adj_power=cdf('NORMAL',0,LOG(1.5)+1.96*(SQRT(((little_r*crude_RR + 1)**2)/(total_events*little_r*crude_RR))/SQRT(1-R_squared_Mean)),(SQRT(((little_r*crude_RR + 1)**2)/(total_events*little_r*crude_RR))/SQRT(1-R_squared_Mean)));

if Estimate_Mean > 0 then
SE2_adj_power=1-cdf('NORMAL',0,LOG(1.5)-1.96*(SQRT(((little_r_tilde*crude_RR + 1)**2)/(total_events*little_r_tilde*crude_RR))/SQRT(1-R_squared_Mean)),(SQRT(((little_r_tilde*crude_RR + 1)**2)/(total_events*little_r_tilde*crude_RR))/SQRT(1-R_squared_Mean)));
else SE2_adj_power=cdf('NORMAL',0,LOG(1.5)+1.96*(SQRT(((little_r_tilde*crude_RR + 1)**2)/(total_events*little_r_tilde*crude_RR))/SQRT(1-R_squared_Mean)),(SQRT(((little_r_tilde*crude_RR + 1)**2)/(total_events*little_r_tilde*crude_RR))/SQRT(1-R_squared_Mean)));

if Estimate_Mean > 0 then
SE3_adj_power=1-cdf('NORMAL',0,LOG(1.5)-1.96*(SQRT((1/treatment_count_Mean + 1/control_count_Mean)/(1-R_squared_Mean))),SQRT((1/treatment_count_Mean + 1/control_count_Mean)/(1-R_squared_Mean)));
else SE3_adj_power=cdf('NORMAL',0,LOG(1.5)+1.96*(SQRT((1/treatment_count_Mean + 1/control_count_Mean)/(1-R_squared_Mean))),SQRT((1/treatment_count_Mean + 1/control_count_Mean)/(1-R_squared_Mean)));

power_sim = prob_lcl_above_1_Mean;
SE_margin = StdErr_StdDev / SQRT(StdErr_N);
Power_margin = SQRT(power_sim*(1-power_sim)/StdErr_N);
options nosource nonotes;
run;

/* SETTING 3 */

ods graphics off;
ods html close;
ods listing;

DATA TEST;
INPUT Subject COUNT;
CARDS;
1 1000
;RUN;

DATA TEST (DROP=subject count);
	SET TEST;
	DO i=1 TO COUNT;
	OUTPUT;
	END;
RUN;

data test (DROP=i);
set test;
Subject = i;
run;

data test;
set test;
if Subject =< 750  then treatment = 1;
else treatment = 0;
run;


%MACRO trial(NUMSAMP=, INDSET=, HR=, OUTDSET=);
	%LET BEGINTIME=%SYSFUNC(TIME());
	DM LOG 'CLEAR';

	PROC DATASETS LIBRARY=WORK;
		DELETE &OUTDSET;
    options nosource nonotes;
	RUN;QUIT;
	PROC DATASETS LIBRARY=WORK;
		DELETE OPUT;
    options nosource nonotes;
	RUN;QUIT;

	ODS LISTING CLOSE;

	%DO i = 1 %TO &NUMSAMP;
data realization&i;
set &indset;
if treatment = 1 then covariate = ranbin(&i,1,0.9);
else covariate = ranbin(&i+10000,1,0.3);

if treatment = 1 AND covariate = 1
then X = ranexp(&i+20000)/(0.12*&HR);
else if treatment = 0 AND covariate = 1
then X = ranexp(&i+30000)/0.12;
else if treatment = 1 AND covariate = 0
then X = ranexp(&i+40000)/(0.06*&HR);
else X = ranexp(&i+50000)/0.06;

C = uniform(&i+60000)*2 + 3;
if treatment = 1 then H = ranexp(&i+70000)/0.05;
else H = ranexp(&i+80000)/0.05;
if X < C AND X < H then Y = 1;
else Y = 0;
T = min(X,C,H);
if H < C AND H < X then Z = 1;
else Z = 0;
if Y = 0 AND Z = 0 then S = 1;
else S = 0;
treat_b = 0.405;
covar_b = 0.693;
w = EXP(treatment*treat_b + covariate*covar_b);
options nosource nonotes;
run;

ods output ParameterEstimates = Oput_Cox&i;
proc phreg data=realization&i;
model T*Y(0)=treatment covariate / risklimits;
options nosource nonotes;
run;

ods output Summary=treatment_count&i;
proc means data=realization&i sum;
var Y Z S T;
where treatment=1;
options nosource nonotes;
run;

data treatment_count&i (drop = Y_sum Z_sum S_sum T_sum);
set treatment_count&i;
treatment_count = Y_sum;
treatment_competing = Z_sum;
treatment_non_event = S_sum;
treatment_time = T_sum;
options nosource nonotes;
run;

ods output Summary=control_count&i;
proc means data=realization&i sum;
var Y Z T S;
where treatment=0;
options nosource nonotes;
run;

data control_count&i (drop = Y_sum Z_sum S_sum T_sum);
set control_count&i;
control_count = Y_sum;
control_competing = Z_sum;
control_non_event = S_sum;
control_time = T_sum;
options nosource nonotes;
run;

ods output PearsonCorr=Corr&i;
proc corr data=realization&i;
var treatment covariate;
weight w;
run;

data corr&i;
set corr&i;
if Variable = 'covariate' then delete;
run;

ods output Summary=treatment_prev&i;
proc means data=realization&i mean;
var treatment;
options nosource nonotes;
run;

data Oput&i;
merge Oput_Cox&i treatment_count&i control_count&i corr&i
treatment_prev&i;
run;

		PROC APPEND BASE=&OUTDSET NEW=OPUT&i FORCE;
		RUN;

		PROC DATASETS LIBRARY=WORK;
			DELETE OPUT&i SAMP&i Oput_Cox&i treatment_count&i control_count&i corr&i
            treatment_prev&i realization&i;
		RUN;QUIT;

%END;
	ODS LISTING;


	%LET ENDTIME=%SYSFUNC(TIME());
	%LET TOTALTIME=%SYSFUNC(ROUND(%SYSEVALF(&ENDTIME-&BEGINTIME),.01));


	%LET ENDTIME=%SYSFUNC(TIME());
	%LET TOTALTIME=%SYSFUNC(ROUND(%SYSEVALF(&ENDTIME-&BEGINTIME),.01));
	%PUT TOTAL TIME FOR MACRO TO RUN (SECONDS) = &TOTALTIME;

%MEND trial;

%trial(NUMSAMP=2000, INDSET=test, HR=1.5, OUTDSET=DONE);

data done;
set done;
if Parameter = 'covariate' then delete;
R_squared = covariate*covariate;
if HRLowerCL < 1.5 < HRUpperCL then coverage = 1;
else coverage = 0;
if HRLowerCL > 1 then prob_lcl_above_1 = 1;
else prob_lcl_above_1  = 0;
run;

ods output Summary=Final;
proc means data=done n mean std nolabels median;
var treatment_count treatment_competing treatment_non_event treatment_time
control_count control_competing control_non_event control_time
R_squared 
Estimate HazardRatio HRLowerCL HRUpperCL coverage StdErr 
prob_lcl_above_1
treatment_Mean;
options nosource nonotes;
run;

data final3;
set final;
little_r = (treatment_Mean_Mean)/(1-treatment_Mean_Mean);
total_events = treatment_count_Mean + control_count_Mean;
crude_RR = (treatment_count_Mean / treatment_time_Mean)/(control_count_Mean/control_time_mean);
little_r_prime = treatment_non_event_Mean / control_non_event_Mean;
little_r_tilde = (little_r + little_r_prime)/2;

SE0 = (SQRT(((little_r + 1)**2)/(total_events*little_r)))/StdErr_Mean;
SE0_adj = (SQRT(((little_r + 1)**2)/(total_events*little_r))/SQRT(1-R_squared_Mean))/StdErr_Mean;

SE1 = (SQRT(((little_r*crude_RR + 1)**2)/(total_events*little_r*crude_RR)))/StdErr_Mean;
SE1_adj = (SQRT(((little_r*crude_RR + 1)**2)/(total_events*little_r*crude_RR))/SQRT(1-R_squared_Mean))/StdErr_Mean;

SE2 = (SQRT(((little_r_tilde*crude_RR + 1)**2)/(total_events*little_r_tilde*crude_RR)))/StdErr_Mean;
SE2_adj = (SQRT(((little_r_tilde*crude_RR + 1)**2)/(total_events*little_r_tilde*crude_RR))/SQRT(1-R_squared_Mean))/StdErr_Mean;

SE3 = (SQRT(1/treatment_count_Mean + 1/control_count_Mean))/StdErr_Mean;
SE3_adj = SQRT((1/treatment_count_Mean + 1/control_count_Mean)/(1-R_squared_Mean))/StdErr_Mean;


SE0_adj_LCL = EXP(Estimate_Mean - 1.96*(SQRT(((little_r + 1)**2)/(total_events*little_r))/SQRT(1-R_squared_Mean)));
SE1_adj_LCL = EXP(Estimate_Mean - 1.96*(SQRT(((little_r*crude_RR + 1)**2)/(total_events*little_r*crude_RR))/SQRT(1-R_squared_Mean)));
SE2_adj_LCL = EXP(Estimate_Mean - 1.96*(SQRT(((little_r_tilde*crude_RR + 1)**2)/(total_events*little_r_tilde*crude_RR))/SQRT(1-R_squared_Mean)));
SE3_adj_LCL = EXP(Estimate_Mean - 1.96*SQRT((1/treatment_count_Mean + 1/control_count_Mean)/(1-R_squared_Mean)));
LCL_sim = HRLowerCL_Mean;

SE0_adj_UCL = EXP(Estimate_Mean + 1.96*(SQRT(((little_r + 1)**2)/(total_events*little_r))/SQRT(1-R_squared_Mean)));
SE1_adj_UCL = EXP(Estimate_Mean + 1.96*(SQRT(((little_r*crude_RR + 1)**2)/(total_events*little_r*crude_RR))/SQRT(1-R_squared_Mean)));
SE2_adj_UCL = EXP(Estimate_Mean + 1.96*(SQRT(((little_r_tilde*crude_RR + 1)**2)/(total_events*little_r_tilde*crude_RR))/SQRT(1-R_squared_Mean)));
SE3_adj_UCL = EXP(Estimate_Mean + 1.96*SQRT((1/treatment_count_Mean + 1/control_count_Mean)/(1-R_squared_Mean)));
UCL_sim = HRUpperCL_Mean;

if Estimate_Mean > 0 then
SE0_adj_power=1-cdf('NORMAL',0,LOG(1.5)-1.96*(SQRT(((little_r + 1)**2)/(total_events*little_r))/SQRT(1-R_squared_Mean)),(SQRT(((little_r + 1)**2)/(total_events*little_r))/SQRT(1-R_squared_Mean)));
else SE0_adj_power=cdf('NORMAL',0,LOG(1.5)+1.96*(SQRT(((little_r + 1)**2)/(total_events*little_r))/SQRT(1-R_squared_Mean)),(SQRT(((little_r + 1)**2)/(total_events*little_r))/SQRT(1-R_squared_Mean)));

if Estimate_Mean > 0 then
SE1_adj_power=1-cdf('NORMAL',0,LOG(1.5)-1.96*(SQRT(((little_r*crude_RR + 1)**2)/(total_events*little_r*crude_RR))/SQRT(1-R_squared_Mean)),(SQRT(((little_r*crude_RR + 1)**2)/(total_events*little_r*crude_RR))/SQRT(1-R_squared_Mean)));
else SE1_adj_power=cdf('NORMAL',0,LOG(1.5)+1.96*(SQRT(((little_r*crude_RR + 1)**2)/(total_events*little_r*crude_RR))/SQRT(1-R_squared_Mean)),(SQRT(((little_r*crude_RR + 1)**2)/(total_events*little_r*crude_RR))/SQRT(1-R_squared_Mean)));

if Estimate_Mean > 0 then
SE2_adj_power=1-cdf('NORMAL',0,LOG(1.5)-1.96*(SQRT(((little_r_tilde*crude_RR + 1)**2)/(total_events*little_r_tilde*crude_RR))/SQRT(1-R_squared_Mean)),(SQRT(((little_r_tilde*crude_RR + 1)**2)/(total_events*little_r_tilde*crude_RR))/SQRT(1-R_squared_Mean)));
else SE2_adj_power=cdf('NORMAL',0,LOG(1.5)+1.96*(SQRT(((little_r_tilde*crude_RR + 1)**2)/(total_events*little_r_tilde*crude_RR))/SQRT(1-R_squared_Mean)),(SQRT(((little_r_tilde*crude_RR + 1)**2)/(total_events*little_r_tilde*crude_RR))/SQRT(1-R_squared_Mean)));

if Estimate_Mean > 0 then
SE3_adj_power=1-cdf('NORMAL',0,LOG(1.5)-1.96*(SQRT((1/treatment_count_Mean + 1/control_count_Mean)/(1-R_squared_Mean))),SQRT((1/treatment_count_Mean + 1/control_count_Mean)/(1-R_squared_Mean)));
else SE3_adj_power=cdf('NORMAL',0,LOG(1.5)+1.96*(SQRT((1/treatment_count_Mean + 1/control_count_Mean)/(1-R_squared_Mean))),SQRT((1/treatment_count_Mean + 1/control_count_Mean)/(1-R_squared_Mean)));

power_sim = prob_lcl_above_1_Mean;
SE_margin = StdErr_StdDev / SQRT(StdErr_N);
Power_margin = SQRT(power_sim*(1-power_sim)/StdErr_N);
options nosource nonotes;
run;

/* SETTING 4 */

ods graphics off;
ods html close;
ods listing;

DATA TEST;
INPUT Subject COUNT;
CARDS;
1 1000
;RUN;

DATA TEST (DROP=subject count);
	SET TEST;
	DO i=1 TO COUNT;
	OUTPUT;
	END;
RUN;

data test (DROP=i);
set test;
Subject = i;
run;

data test;
set test;
if Subject =< 500 then treatment = 1;
else treatment = 0;
run;


%MACRO trial(NUMSAMP=, INDSET=, HR=, OUTDSET=);
	%LET BEGINTIME=%SYSFUNC(TIME());
	DM LOG 'CLEAR';

	PROC DATASETS LIBRARY=WORK;
		DELETE &OUTDSET;
    options nosource nonotes;
	RUN;QUIT;
	PROC DATASETS LIBRARY=WORK;
		DELETE OPUT;
    options nosource nonotes;
	RUN;QUIT;

	ODS LISTING CLOSE;

	%DO i = 1 %TO &NUMSAMP;
data realization&i;
set &indset;
if treatment = 1 then covariate = ranbin(&i,1,0.3);
else covariate = ranbin(&i+10000,1,0.3);

if treatment = 1 AND covariate = 1
then X = ranexp(&i+20000)/(0.12*&HR);
else if treatment = 0 AND covariate = 1
then X = ranexp(&i+30000)/0.12;
else if treatment = 1 AND covariate = 0
then X = ranexp(&i+40000)/(0.06*&HR);
else X = ranexp(&i+50000)/0.06;

C = uniform(&i+60000)*2 + 3;
if treatment = 1 then H = ranexp(&i+70000)/0.05;
else H = ranexp(&i+80000)/0.05;
if X < C AND X < H then Y = 1;
else Y = 0;
T = min(X,C,H);
if H < C AND H < X then Z = 1;
else Z = 0;
if Y = 0 AND Z = 0 then S = 1;
else S = 0;
treat_b = 0.405;
covar_b = 0.693;
w = EXP(treatment*treat_b + covariate*covar_b);
options nosource nonotes;
run;

ods output ParameterEstimates = Oput_Cox&i;
proc phreg data=realization&i;
model T*Y(0)=treatment covariate / risklimits;
options nosource nonotes;
run;

ods output Summary=treatment_count&i;
proc means data=realization&i sum;
var Y Z S T;
where treatment=1;
options nosource nonotes;
run;

data treatment_count&i (drop = Y_sum Z_sum S_sum T_sum);
set treatment_count&i;
treatment_count = Y_sum;
treatment_competing = Z_sum;
treatment_non_event = S_sum;
treatment_time = T_sum;
options nosource nonotes;
run;

ods output Summary=control_count&i;
proc means data=realization&i sum;
var Y Z T S;
where treatment=0;
options nosource nonotes;
run;

data control_count&i (drop = Y_sum Z_sum S_sum T_sum);
set control_count&i;
control_count = Y_sum;
control_competing = Z_sum;
control_non_event = S_sum;
control_time = T_sum;
options nosource nonotes;
run;

ods output PearsonCorr=Corr&i;
proc corr data=realization&i;
var treatment covariate;
weight w;
run;

data corr&i;
set corr&i;
if Variable = 'covariate' then delete;
run;

ods output Summary=treatment_prev&i;
proc means data=realization&i mean;
var treatment;
options nosource nonotes;
run;

data Oput&i;
merge Oput_Cox&i treatment_count&i control_count&i corr&i
treatment_prev&i;
run;

		PROC APPEND BASE=&OUTDSET NEW=OPUT&i FORCE;
		RUN;

		PROC DATASETS LIBRARY=WORK;
			DELETE OPUT&i SAMP&i Oput_Cox&i treatment_count&i control_count&i corr&i
            treatment_prev&i realization&i;
		RUN;QUIT;

%END;
	ODS LISTING;


	%LET ENDTIME=%SYSFUNC(TIME());
	%LET TOTALTIME=%SYSFUNC(ROUND(%SYSEVALF(&ENDTIME-&BEGINTIME),.01));


	%LET ENDTIME=%SYSFUNC(TIME());
	%LET TOTALTIME=%SYSFUNC(ROUND(%SYSEVALF(&ENDTIME-&BEGINTIME),.01));
	%PUT TOTAL TIME FOR MACRO TO RUN (SECONDS) = &TOTALTIME;

%MEND trial;

%trial(NUMSAMP=2000, INDSET=test, HR=1.5, OUTDSET=DONE);

data done;
set done;
if Parameter = 'covariate' then delete;
R_squared = covariate*covariate;
if HRLowerCL < 1.5 < HRUpperCL then coverage = 1;
else coverage = 0;
if HRLowerCL > 1 then prob_lcl_above_1 = 1;
else prob_lcl_above_1  = 0;
run;

ods output Summary=Final;
proc means data=done n mean std nolabels median;
var treatment_count treatment_competing treatment_non_event treatment_time
control_count control_competing control_non_event control_time
R_squared 
Estimate HazardRatio HRLowerCL HRUpperCL coverage StdErr 
prob_lcl_above_1
treatment_Mean;
options nosource nonotes;
run;

data final4;
set final;
little_r = (treatment_Mean_Mean)/(1-treatment_Mean_Mean);
total_events = treatment_count_Mean + control_count_Mean;
crude_RR = (treatment_count_Mean / treatment_time_Mean)/(control_count_Mean/control_time_mean);
little_r_prime = treatment_non_event_Mean / control_non_event_Mean;
little_r_tilde = (little_r + little_r_prime)/2;

SE0 = (SQRT(((little_r + 1)**2)/(total_events*little_r)))/StdErr_Mean;
SE0_adj = (SQRT(((little_r + 1)**2)/(total_events*little_r))/SQRT(1-R_squared_Mean))/StdErr_Mean;

SE1 = (SQRT(((little_r*crude_RR + 1)**2)/(total_events*little_r*crude_RR)))/StdErr_Mean;
SE1_adj = (SQRT(((little_r*crude_RR + 1)**2)/(total_events*little_r*crude_RR))/SQRT(1-R_squared_Mean))/StdErr_Mean;

SE2 = (SQRT(((little_r_tilde*crude_RR + 1)**2)/(total_events*little_r_tilde*crude_RR)))/StdErr_Mean;
SE2_adj = (SQRT(((little_r_tilde*crude_RR + 1)**2)/(total_events*little_r_tilde*crude_RR))/SQRT(1-R_squared_Mean))/StdErr_Mean;

SE3 = (SQRT(1/treatment_count_Mean + 1/control_count_Mean))/StdErr_Mean;
SE3_adj = SQRT((1/treatment_count_Mean + 1/control_count_Mean)/(1-R_squared_Mean))/StdErr_Mean;


SE0_adj_LCL = EXP(Estimate_Mean - 1.96*(SQRT(((little_r + 1)**2)/(total_events*little_r))/SQRT(1-R_squared_Mean)));
SE1_adj_LCL = EXP(Estimate_Mean - 1.96*(SQRT(((little_r*crude_RR + 1)**2)/(total_events*little_r*crude_RR))/SQRT(1-R_squared_Mean)));
SE2_adj_LCL = EXP(Estimate_Mean - 1.96*(SQRT(((little_r_tilde*crude_RR + 1)**2)/(total_events*little_r_tilde*crude_RR))/SQRT(1-R_squared_Mean)));
SE3_adj_LCL = EXP(Estimate_Mean - 1.96*SQRT((1/treatment_count_Mean + 1/control_count_Mean)/(1-R_squared_Mean)));
LCL_sim = HRLowerCL_Mean;

SE0_adj_UCL = EXP(Estimate_Mean + 1.96*(SQRT(((little_r + 1)**2)/(total_events*little_r))/SQRT(1-R_squared_Mean)));
SE1_adj_UCL = EXP(Estimate_Mean + 1.96*(SQRT(((little_r*crude_RR + 1)**2)/(total_events*little_r*crude_RR))/SQRT(1-R_squared_Mean)));
SE2_adj_UCL = EXP(Estimate_Mean + 1.96*(SQRT(((little_r_tilde*crude_RR + 1)**2)/(total_events*little_r_tilde*crude_RR))/SQRT(1-R_squared_Mean)));
SE3_adj_UCL = EXP(Estimate_Mean + 1.96*SQRT((1/treatment_count_Mean + 1/control_count_Mean)/(1-R_squared_Mean)));
UCL_sim = HRUpperCL_Mean;

if Estimate_Mean > 0 then
SE0_adj_power=1-cdf('NORMAL',0,LOG(1.5)-1.96*(SQRT(((little_r + 1)**2)/(total_events*little_r))/SQRT(1-R_squared_Mean)),(SQRT(((little_r + 1)**2)/(total_events*little_r))/SQRT(1-R_squared_Mean)));
else SE0_adj_power=cdf('NORMAL',0,LOG(1.5)+1.96*(SQRT(((little_r + 1)**2)/(total_events*little_r))/SQRT(1-R_squared_Mean)),(SQRT(((little_r + 1)**2)/(total_events*little_r))/SQRT(1-R_squared_Mean)));

if Estimate_Mean > 0 then
SE1_adj_power=1-cdf('NORMAL',0,LOG(1.5)-1.96*(SQRT(((little_r*crude_RR + 1)**2)/(total_events*little_r*crude_RR))/SQRT(1-R_squared_Mean)),(SQRT(((little_r*crude_RR + 1)**2)/(total_events*little_r*crude_RR))/SQRT(1-R_squared_Mean)));
else SE1_adj_power=cdf('NORMAL',0,LOG(1.5)+1.96*(SQRT(((little_r*crude_RR + 1)**2)/(total_events*little_r*crude_RR))/SQRT(1-R_squared_Mean)),(SQRT(((little_r*crude_RR + 1)**2)/(total_events*little_r*crude_RR))/SQRT(1-R_squared_Mean)));

if Estimate_Mean > 0 then
SE2_adj_power=1-cdf('NORMAL',0,LOG(1.5)-1.96*(SQRT(((little_r_tilde*crude_RR + 1)**2)/(total_events*little_r_tilde*crude_RR))/SQRT(1-R_squared_Mean)),(SQRT(((little_r_tilde*crude_RR + 1)**2)/(total_events*little_r_tilde*crude_RR))/SQRT(1-R_squared_Mean)));
else SE2_adj_power=cdf('NORMAL',0,LOG(1.5)+1.96*(SQRT(((little_r_tilde*crude_RR + 1)**2)/(total_events*little_r_tilde*crude_RR))/SQRT(1-R_squared_Mean)),(SQRT(((little_r_tilde*crude_RR + 1)**2)/(total_events*little_r_tilde*crude_RR))/SQRT(1-R_squared_Mean)));

if Estimate_Mean > 0 then
SE3_adj_power=1-cdf('NORMAL',0,LOG(1.5)-1.96*(SQRT((1/treatment_count_Mean + 1/control_count_Mean)/(1-R_squared_Mean))),SQRT((1/treatment_count_Mean + 1/control_count_Mean)/(1-R_squared_Mean)));
else SE3_adj_power=cdf('NORMAL',0,LOG(1.5)+1.96*(SQRT((1/treatment_count_Mean + 1/control_count_Mean)/(1-R_squared_Mean))),SQRT((1/treatment_count_Mean + 1/control_count_Mean)/(1-R_squared_Mean)));

power_sim = prob_lcl_above_1_Mean;
SE_margin = StdErr_StdDev / SQRT(StdErr_N);
Power_margin = SQRT(power_sim*(1-power_sim)/StdErr_N);
options nosource nonotes;
run;

/* SETTING 5 */
ods graphics off;
ods html close;
ods listing;

DATA TEST;
INPUT Subject COUNT;
CARDS;
1 1000
;RUN;

DATA TEST (DROP=subject count);
	SET TEST;
	DO i=1 TO COUNT;
	OUTPUT;
	END;
RUN;

data test (DROP=i);
set test;
Subject = i;
run;

data test;
set test;
if Subject =< 500 then treatment = 1;
else treatment = 0;
run;


%MACRO trial(NUMSAMP=, INDSET=, HR=, OUTDSET=);
	%LET BEGINTIME=%SYSFUNC(TIME());
	DM LOG 'CLEAR';

	PROC DATASETS LIBRARY=WORK;
		DELETE &OUTDSET;
    options nosource nonotes;
	RUN;QUIT;
	PROC DATASETS LIBRARY=WORK;
		DELETE OPUT;
    options nosource nonotes;
	RUN;QUIT;

	ODS LISTING CLOSE;

	%DO i = 1 %TO &NUMSAMP;
data realization&i;
set &indset;
if treatment = 1 then covariate = ranbin(&i,1,0.6);
else covariate = ranbin(&i+10000,1,0.3);

if treatment = 1 AND covariate = 1
then X = ranexp(&i+20000)/(0.12*&HR);
else if treatment = 0 AND covariate = 1
then X = ranexp(&i+30000)/0.12;
else if treatment = 1 AND covariate = 0
then X = ranexp(&i+40000)/(0.06*&HR);
else X = ranexp(&i+50000)/0.06;

C = uniform(&i+60000)*2 + 3;
if treatment = 1 then H = ranexp(&i+70000)/0.05;
else H = ranexp(&i+80000)/0.05;
if X < C AND X < H then Y = 1;
else Y = 0;
T = min(X,C,H);
if H < C AND H < X then Z = 1;
else Z = 0;
if Y = 0 AND Z = 0 then S = 1;
else S = 0;
treat_b = 0.405;
covar_b = 0.693;
w = EXP(treatment*treat_b + covariate*covar_b);
options nosource nonotes;
run;

ods output ParameterEstimates = Oput_Cox&i;
proc phreg data=realization&i;
model T*Y(0)=treatment covariate / risklimits;
options nosource nonotes;
run;

ods output Summary=treatment_count&i;
proc means data=realization&i sum;
var Y Z S T;
where treatment=1;
options nosource nonotes;
run;

data treatment_count&i (drop = Y_sum Z_sum S_sum T_sum);
set treatment_count&i;
treatment_count = Y_sum;
treatment_competing = Z_sum;
treatment_non_event = S_sum;
treatment_time = T_sum;
options nosource nonotes;
run;

ods output Summary=control_count&i;
proc means data=realization&i sum;
var Y Z T S;
where treatment=0;
options nosource nonotes;
run;

data control_count&i (drop = Y_sum Z_sum S_sum T_sum);
set control_count&i;
control_count = Y_sum;
control_competing = Z_sum;
control_non_event = S_sum;
control_time = T_sum;
options nosource nonotes;
run;

ods output PearsonCorr=Corr&i;
proc corr data=realization&i;
var treatment covariate;
weight w;
run;

data corr&i;
set corr&i;
if Variable = 'covariate' then delete;
run;

ods output Summary=treatment_prev&i;
proc means data=realization&i mean;
var treatment;
options nosource nonotes;
run;

data Oput&i;
merge Oput_Cox&i treatment_count&i control_count&i corr&i
treatment_prev&i;
run;

		PROC APPEND BASE=&OUTDSET NEW=OPUT&i FORCE;
		RUN;

		PROC DATASETS LIBRARY=WORK;
			DELETE OPUT&i SAMP&i Oput_Cox&i treatment_count&i control_count&i corr&i
            treatment_prev&i realization&i;
		RUN;QUIT;

%END;
	ODS LISTING;


	%LET ENDTIME=%SYSFUNC(TIME());
	%LET TOTALTIME=%SYSFUNC(ROUND(%SYSEVALF(&ENDTIME-&BEGINTIME),.01));


	%LET ENDTIME=%SYSFUNC(TIME());
	%LET TOTALTIME=%SYSFUNC(ROUND(%SYSEVALF(&ENDTIME-&BEGINTIME),.01));
	%PUT TOTAL TIME FOR MACRO TO RUN (SECONDS) = &TOTALTIME;

%MEND trial;

%trial(NUMSAMP=2000, INDSET=test, HR=1.5, OUTDSET=DONE);

data done;
set done;
if Parameter = 'covariate' then delete;
R_squared = covariate*covariate;
if HRLowerCL < 1.5 < HRUpperCL then coverage = 1;
else coverage = 0;
if HRLowerCL > 1 then prob_lcl_above_1 = 1;
else prob_lcl_above_1  = 0;
run;

ods output Summary=Final;
proc means data=done n mean std nolabels median;
var treatment_count treatment_competing treatment_non_event treatment_time
control_count control_competing control_non_event control_time
R_squared 
Estimate HazardRatio HRLowerCL HRUpperCL coverage StdErr 
prob_lcl_above_1
treatment_Mean;
options nosource nonotes;
run;

data final5;
set final;
little_r = (treatment_Mean_Mean)/(1-treatment_Mean_Mean);
total_events = treatment_count_Mean + control_count_Mean;
crude_RR = (treatment_count_Mean / treatment_time_Mean)/(control_count_Mean/control_time_mean);
little_r_prime = treatment_non_event_Mean / control_non_event_Mean;
little_r_tilde = (little_r + little_r_prime)/2;

SE0 = (SQRT(((little_r + 1)**2)/(total_events*little_r)))/StdErr_Mean;
SE0_adj = (SQRT(((little_r + 1)**2)/(total_events*little_r))/SQRT(1-R_squared_Mean))/StdErr_Mean;

SE1 = (SQRT(((little_r*crude_RR + 1)**2)/(total_events*little_r*crude_RR)))/StdErr_Mean;
SE1_adj = (SQRT(((little_r*crude_RR + 1)**2)/(total_events*little_r*crude_RR))/SQRT(1-R_squared_Mean))/StdErr_Mean;

SE2 = (SQRT(((little_r_tilde*crude_RR + 1)**2)/(total_events*little_r_tilde*crude_RR)))/StdErr_Mean;
SE2_adj = (SQRT(((little_r_tilde*crude_RR + 1)**2)/(total_events*little_r_tilde*crude_RR))/SQRT(1-R_squared_Mean))/StdErr_Mean;

SE3 = (SQRT(1/treatment_count_Mean + 1/control_count_Mean))/StdErr_Mean;
SE3_adj = SQRT((1/treatment_count_Mean + 1/control_count_Mean)/(1-R_squared_Mean))/StdErr_Mean;


SE0_adj_LCL = EXP(Estimate_Mean - 1.96*(SQRT(((little_r + 1)**2)/(total_events*little_r))/SQRT(1-R_squared_Mean)));
SE1_adj_LCL = EXP(Estimate_Mean - 1.96*(SQRT(((little_r*crude_RR + 1)**2)/(total_events*little_r*crude_RR))/SQRT(1-R_squared_Mean)));
SE2_adj_LCL = EXP(Estimate_Mean - 1.96*(SQRT(((little_r_tilde*crude_RR + 1)**2)/(total_events*little_r_tilde*crude_RR))/SQRT(1-R_squared_Mean)));
SE3_adj_LCL = EXP(Estimate_Mean - 1.96*SQRT((1/treatment_count_Mean + 1/control_count_Mean)/(1-R_squared_Mean)));
LCL_sim = HRLowerCL_Mean;

SE0_adj_UCL = EXP(Estimate_Mean + 1.96*(SQRT(((little_r + 1)**2)/(total_events*little_r))/SQRT(1-R_squared_Mean)));
SE1_adj_UCL = EXP(Estimate_Mean + 1.96*(SQRT(((little_r*crude_RR + 1)**2)/(total_events*little_r*crude_RR))/SQRT(1-R_squared_Mean)));
SE2_adj_UCL = EXP(Estimate_Mean + 1.96*(SQRT(((little_r_tilde*crude_RR + 1)**2)/(total_events*little_r_tilde*crude_RR))/SQRT(1-R_squared_Mean)));
SE3_adj_UCL = EXP(Estimate_Mean + 1.96*SQRT((1/treatment_count_Mean + 1/control_count_Mean)/(1-R_squared_Mean)));
UCL_sim = HRUpperCL_Mean;

if Estimate_Mean > 0 then
SE0_adj_power=1-cdf('NORMAL',0,LOG(1.5)-1.96*(SQRT(((little_r + 1)**2)/(total_events*little_r))/SQRT(1-R_squared_Mean)),(SQRT(((little_r + 1)**2)/(total_events*little_r))/SQRT(1-R_squared_Mean)));
else SE0_adj_power=cdf('NORMAL',0,LOG(1.5)+1.96*(SQRT(((little_r + 1)**2)/(total_events*little_r))/SQRT(1-R_squared_Mean)),(SQRT(((little_r + 1)**2)/(total_events*little_r))/SQRT(1-R_squared_Mean)));

if Estimate_Mean > 0 then
SE1_adj_power=1-cdf('NORMAL',0,LOG(1.5)-1.96*(SQRT(((little_r*crude_RR + 1)**2)/(total_events*little_r*crude_RR))/SQRT(1-R_squared_Mean)),(SQRT(((little_r*crude_RR + 1)**2)/(total_events*little_r*crude_RR))/SQRT(1-R_squared_Mean)));
else SE1_adj_power=cdf('NORMAL',0,LOG(1.5)+1.96*(SQRT(((little_r*crude_RR + 1)**2)/(total_events*little_r*crude_RR))/SQRT(1-R_squared_Mean)),(SQRT(((little_r*crude_RR + 1)**2)/(total_events*little_r*crude_RR))/SQRT(1-R_squared_Mean)));

if Estimate_Mean > 0 then
SE2_adj_power=1-cdf('NORMAL',0,LOG(1.5)-1.96*(SQRT(((little_r_tilde*crude_RR + 1)**2)/(total_events*little_r_tilde*crude_RR))/SQRT(1-R_squared_Mean)),(SQRT(((little_r_tilde*crude_RR + 1)**2)/(total_events*little_r_tilde*crude_RR))/SQRT(1-R_squared_Mean)));
else SE2_adj_power=cdf('NORMAL',0,LOG(1.5)+1.96*(SQRT(((little_r_tilde*crude_RR + 1)**2)/(total_events*little_r_tilde*crude_RR))/SQRT(1-R_squared_Mean)),(SQRT(((little_r_tilde*crude_RR + 1)**2)/(total_events*little_r_tilde*crude_RR))/SQRT(1-R_squared_Mean)));

if Estimate_Mean > 0 then
SE3_adj_power=1-cdf('NORMAL',0,LOG(1.5)-1.96*(SQRT((1/treatment_count_Mean + 1/control_count_Mean)/(1-R_squared_Mean))),SQRT((1/treatment_count_Mean + 1/control_count_Mean)/(1-R_squared_Mean)));
else SE3_adj_power=cdf('NORMAL',0,LOG(1.5)+1.96*(SQRT((1/treatment_count_Mean + 1/control_count_Mean)/(1-R_squared_Mean))),SQRT((1/treatment_count_Mean + 1/control_count_Mean)/(1-R_squared_Mean)));

power_sim = prob_lcl_above_1_Mean;
SE_margin = StdErr_StdDev / SQRT(StdErr_N);
Power_margin = SQRT(power_sim*(1-power_sim)/StdErr_N);
options nosource nonotes;
run;

/* SETTING 6 */
ods graphics off;
ods html close;
ods listing;

DATA TEST;
INPUT Subject COUNT;
CARDS;
1 1000
;RUN;

DATA TEST (DROP=subject count);
	SET TEST;
	DO i=1 TO COUNT;
	OUTPUT;
	END;
RUN;

data test (DROP=i);
set test;
Subject = i;
run;

data test;
set test;
if Subject =< 500 then treatment = 1;
else treatment = 0;
run;


%MACRO trial(NUMSAMP=, INDSET=, HR=, OUTDSET=);
	%LET BEGINTIME=%SYSFUNC(TIME());
	DM LOG 'CLEAR';

	PROC DATASETS LIBRARY=WORK;
		DELETE &OUTDSET;
    options nosource nonotes;
	RUN;QUIT;
	PROC DATASETS LIBRARY=WORK;
		DELETE OPUT;
    options nosource nonotes;
	RUN;QUIT;

	ODS LISTING CLOSE;

	%DO i = 1 %TO &NUMSAMP;
data realization&i;
set &indset;
if treatment = 1 then covariate = ranbin(&i,1,0.9);
else covariate = ranbin(&i+10000,1,0.3);

if treatment = 1 AND covariate = 1
then X = ranexp(&i+20000)/(0.12*&HR);
else if treatment = 0 AND covariate = 1
then X = ranexp(&i+30000)/0.12;
else if treatment = 1 AND covariate = 0
then X = ranexp(&i+40000)/(0.06*&HR);
else X = ranexp(&i+50000)/0.06;

C = uniform(&i+60000)*2 + 3;
if treatment = 1 then H = ranexp(&i+70000)/0.05;
else H = ranexp(&i+80000)/0.05;
if X < C AND X < H then Y = 1;
else Y = 0;
T = min(X,C,H);
if H < C AND H < X then Z = 1;
else Z = 0;
if Y = 0 AND Z = 0 then S = 1;
else S = 0;
treat_b = 0.405;
covar_b = 0.693;
w = EXP(treatment*treat_b + covariate*covar_b);
options nosource nonotes;
run;

ods output ParameterEstimates = Oput_Cox&i;
proc phreg data=realization&i;
model T*Y(0)=treatment covariate / risklimits;
options nosource nonotes;
run;

ods output Summary=treatment_count&i;
proc means data=realization&i sum;
var Y Z S T;
where treatment=1;
options nosource nonotes;
run;

data treatment_count&i (drop = Y_sum Z_sum S_sum T_sum);
set treatment_count&i;
treatment_count = Y_sum;
treatment_competing = Z_sum;
treatment_non_event = S_sum;
treatment_time = T_sum;
options nosource nonotes;
run;

ods output Summary=control_count&i;
proc means data=realization&i sum;
var Y Z T S;
where treatment=0;
options nosource nonotes;
run;

data control_count&i (drop = Y_sum Z_sum S_sum T_sum);
set control_count&i;
control_count = Y_sum;
control_competing = Z_sum;
control_non_event = S_sum;
control_time = T_sum;
options nosource nonotes;
run;

ods output PearsonCorr=Corr&i;
proc corr data=realization&i;
var treatment covariate;
weight w;
run;

data corr&i;
set corr&i;
if Variable = 'covariate' then delete;
run;

ods output Summary=treatment_prev&i;
proc means data=realization&i mean;
var treatment;
options nosource nonotes;
run;

data Oput&i;
merge Oput_Cox&i treatment_count&i control_count&i corr&i
treatment_prev&i;
run;

		PROC APPEND BASE=&OUTDSET NEW=OPUT&i FORCE;
		RUN;

		PROC DATASETS LIBRARY=WORK;
			DELETE OPUT&i SAMP&i Oput_Cox&i treatment_count&i control_count&i corr&i
            treatment_prev&i realization&i;
		RUN;QUIT;

%END;
	ODS LISTING;


	%LET ENDTIME=%SYSFUNC(TIME());
	%LET TOTALTIME=%SYSFUNC(ROUND(%SYSEVALF(&ENDTIME-&BEGINTIME),.01));


	%LET ENDTIME=%SYSFUNC(TIME());
	%LET TOTALTIME=%SYSFUNC(ROUND(%SYSEVALF(&ENDTIME-&BEGINTIME),.01));
	%PUT TOTAL TIME FOR MACRO TO RUN (SECONDS) = &TOTALTIME;

%MEND trial;

%trial(NUMSAMP=2000, INDSET=test, HR=1.5, OUTDSET=DONE);

data done;
set done;
if Parameter = 'covariate' then delete;
R_squared = covariate*covariate;
if HRLowerCL < 1.5 < HRUpperCL then coverage = 1;
else coverage = 0;
if HRLowerCL > 1 then prob_lcl_above_1 = 1;
else prob_lcl_above_1  = 0;
run;

ods output Summary=Final;
proc means data=done n mean std nolabels median;
var treatment_count treatment_competing treatment_non_event treatment_time
control_count control_competing control_non_event control_time
R_squared 
Estimate HazardRatio HRLowerCL HRUpperCL coverage StdErr 
prob_lcl_above_1
treatment_Mean;
options nosource nonotes;
run;

data final6;
set final;
little_r = (treatment_Mean_Mean)/(1-treatment_Mean_Mean);
total_events = treatment_count_Mean + control_count_Mean;
crude_RR = (treatment_count_Mean / treatment_time_Mean)/(control_count_Mean/control_time_mean);
little_r_prime = treatment_non_event_Mean / control_non_event_Mean;
little_r_tilde = (little_r + little_r_prime)/2;

SE0 = (SQRT(((little_r + 1)**2)/(total_events*little_r)))/StdErr_Mean;
SE0_adj = (SQRT(((little_r + 1)**2)/(total_events*little_r))/SQRT(1-R_squared_Mean))/StdErr_Mean;

SE1 = (SQRT(((little_r*crude_RR + 1)**2)/(total_events*little_r*crude_RR)))/StdErr_Mean;
SE1_adj = (SQRT(((little_r*crude_RR + 1)**2)/(total_events*little_r*crude_RR))/SQRT(1-R_squared_Mean))/StdErr_Mean;

SE2 = (SQRT(((little_r_tilde*crude_RR + 1)**2)/(total_events*little_r_tilde*crude_RR)))/StdErr_Mean;
SE2_adj = (SQRT(((little_r_tilde*crude_RR + 1)**2)/(total_events*little_r_tilde*crude_RR))/SQRT(1-R_squared_Mean))/StdErr_Mean;

SE3 = (SQRT(1/treatment_count_Mean + 1/control_count_Mean))/StdErr_Mean;
SE3_adj = SQRT((1/treatment_count_Mean + 1/control_count_Mean)/(1-R_squared_Mean))/StdErr_Mean;

SE0_adj_LCL = EXP(Estimate_Mean - 1.96*(SQRT(((little_r + 1)**2)/(total_events*little_r))/SQRT(1-R_squared_Mean)));
SE1_adj_LCL = EXP(Estimate_Mean - 1.96*(SQRT(((little_r*crude_RR + 1)**2)/(total_events*little_r*crude_RR))/SQRT(1-R_squared_Mean)));
SE2_adj_LCL = EXP(Estimate_Mean - 1.96*(SQRT(((little_r_tilde*crude_RR + 1)**2)/(total_events*little_r_tilde*crude_RR))/SQRT(1-R_squared_Mean)));
SE3_adj_LCL = EXP(Estimate_Mean - 1.96*SQRT((1/treatment_count_Mean + 1/control_count_Mean)/(1-R_squared_Mean)));
LCL_sim = HRLowerCL_Mean;

SE0_adj_UCL = EXP(Estimate_Mean + 1.96*(SQRT(((little_r + 1)**2)/(total_events*little_r))/SQRT(1-R_squared_Mean)));
SE1_adj_UCL = EXP(Estimate_Mean + 1.96*(SQRT(((little_r*crude_RR + 1)**2)/(total_events*little_r*crude_RR))/SQRT(1-R_squared_Mean)));
SE2_adj_UCL = EXP(Estimate_Mean + 1.96*(SQRT(((little_r_tilde*crude_RR + 1)**2)/(total_events*little_r_tilde*crude_RR))/SQRT(1-R_squared_Mean)));
SE3_adj_UCL = EXP(Estimate_Mean + 1.96*SQRT((1/treatment_count_Mean + 1/control_count_Mean)/(1-R_squared_Mean)));
UCL_sim = HRUpperCL_Mean;

if Estimate_Mean > 0 then
SE0_adj_power=1-cdf('NORMAL',0,LOG(1.5)-1.96*(SQRT(((little_r + 1)**2)/(total_events*little_r))/SQRT(1-R_squared_Mean)),(SQRT(((little_r + 1)**2)/(total_events*little_r))/SQRT(1-R_squared_Mean)));
else SE0_adj_power=cdf('NORMAL',0,LOG(1.5)+1.96*(SQRT(((little_r + 1)**2)/(total_events*little_r))/SQRT(1-R_squared_Mean)),(SQRT(((little_r + 1)**2)/(total_events*little_r))/SQRT(1-R_squared_Mean)));

if Estimate_Mean > 0 then
SE1_adj_power=1-cdf('NORMAL',0,LOG(1.5)-1.96*(SQRT(((little_r*crude_RR + 1)**2)/(total_events*little_r*crude_RR))/SQRT(1-R_squared_Mean)),(SQRT(((little_r*crude_RR + 1)**2)/(total_events*little_r*crude_RR))/SQRT(1-R_squared_Mean)));
else SE1_adj_power=cdf('NORMAL',0,LOG(1.5)+1.96*(SQRT(((little_r*crude_RR + 1)**2)/(total_events*little_r*crude_RR))/SQRT(1-R_squared_Mean)),(SQRT(((little_r*crude_RR + 1)**2)/(total_events*little_r*crude_RR))/SQRT(1-R_squared_Mean)));

if Estimate_Mean > 0 then
SE2_adj_power=1-cdf('NORMAL',0,LOG(1.5)-1.96*(SQRT(((little_r_tilde*crude_RR + 1)**2)/(total_events*little_r_tilde*crude_RR))/SQRT(1-R_squared_Mean)),(SQRT(((little_r_tilde*crude_RR + 1)**2)/(total_events*little_r_tilde*crude_RR))/SQRT(1-R_squared_Mean)));
else SE2_adj_power=cdf('NORMAL',0,LOG(1.5)+1.96*(SQRT(((little_r_tilde*crude_RR + 1)**2)/(total_events*little_r_tilde*crude_RR))/SQRT(1-R_squared_Mean)),(SQRT(((little_r_tilde*crude_RR + 1)**2)/(total_events*little_r_tilde*crude_RR))/SQRT(1-R_squared_Mean)));

if Estimate_Mean > 0 then
SE3_adj_power=1-cdf('NORMAL',0,LOG(1.5)-1.96*(SQRT((1/treatment_count_Mean + 1/control_count_Mean)/(1-R_squared_Mean))),SQRT((1/treatment_count_Mean + 1/control_count_Mean)/(1-R_squared_Mean)));
else SE3_adj_power=cdf('NORMAL',0,LOG(1.5)+1.96*(SQRT((1/treatment_count_Mean + 1/control_count_Mean)/(1-R_squared_Mean))),SQRT((1/treatment_count_Mean + 1/control_count_Mean)/(1-R_squared_Mean)));

power_sim = prob_lcl_above_1_Mean;
SE_margin = StdErr_StdDev / SQRT(StdErr_N);
Power_margin = SQRT(power_sim*(1-power_sim)/StdErr_N);
options nosource nonotes;
run;

/* SETTING 7 */
ods graphics off;
ods html close;
ods listing;

DATA TEST;
INPUT Subject COUNT;
CARDS;
1 1000
;RUN;

DATA TEST (DROP=subject count);
	SET TEST;
	DO i=1 TO COUNT;
	OUTPUT;
	END;
RUN;

data test (DROP=i);
set test;
Subject = i;
run;

data test;
set test;
if Subject =< 250 then treatment = 1;
else treatment = 0;
run;


%MACRO trial(NUMSAMP=, INDSET=, HR=, OUTDSET=);
	%LET BEGINTIME=%SYSFUNC(TIME());
	DM LOG 'CLEAR';

	PROC DATASETS LIBRARY=WORK;
		DELETE &OUTDSET;
    options nosource nonotes;
	RUN;QUIT;
	PROC DATASETS LIBRARY=WORK;
		DELETE OPUT;
    options nosource nonotes;
	RUN;QUIT;

	ODS LISTING CLOSE;

	%DO i = 1 %TO &NUMSAMP;
data realization&i;
set &indset;
if treatment = 1 then covariate = ranbin(&i,1,0.3);
else covariate = ranbin(&i+10000,1,0.3);

if treatment = 1 AND covariate = 1
then X = ranexp(&i+20000)/(0.12*&HR);
else if treatment = 0 AND covariate = 1
then X = ranexp(&i+30000)/0.12;
else if treatment = 1 AND covariate = 0
then X = ranexp(&i+40000)/(0.06*&HR);
else X = ranexp(&i+50000)/0.06;

C = uniform(&i+60000)*2 + 3;
if treatment = 1 then H = ranexp(&i+70000)/0.05;
else H = ranexp(&i+80000)/0.05;
if X < C AND X < H then Y = 1;
else Y = 0;
T = min(X,C,H);
if H < C AND H < X then Z = 1;
else Z = 0;
if Y = 0 AND Z = 0 then S = 1;
else S = 0;
treat_b = 0.405;
covar_b = 0.693;
w = EXP(treatment*treat_b + covariate*covar_b);
options nosource nonotes;
run;

ods output ParameterEstimates = Oput_Cox&i;
proc phreg data=realization&i;
model T*Y(0)=treatment covariate / risklimits;
options nosource nonotes;
run;

ods output Summary=treatment_count&i;
proc means data=realization&i sum;
var Y Z S T;
where treatment=1;
options nosource nonotes;
run;

data treatment_count&i (drop = Y_sum Z_sum S_sum T_sum);
set treatment_count&i;
treatment_count = Y_sum;
treatment_competing = Z_sum;
treatment_non_event = S_sum;
treatment_time = T_sum;
options nosource nonotes;
run;

ods output Summary=control_count&i;
proc means data=realization&i sum;
var Y Z T S;
where treatment=0;
options nosource nonotes;
run;

data control_count&i (drop = Y_sum Z_sum S_sum T_sum);
set control_count&i;
control_count = Y_sum;
control_competing = Z_sum;
control_non_event = S_sum;
control_time = T_sum;
options nosource nonotes;
run;

ods output PearsonCorr=Corr&i;
proc corr data=realization&i;
var treatment covariate;
weight w;
run;

data corr&i;
set corr&i;
if Variable = 'covariate' then delete;
run;

ods output Summary=treatment_prev&i;
proc means data=realization&i mean;
var treatment;
options nosource nonotes;
run;

data Oput&i;
merge Oput_Cox&i treatment_count&i control_count&i corr&i
treatment_prev&i;
run;

		PROC APPEND BASE=&OUTDSET NEW=OPUT&i FORCE;
		RUN;

		PROC DATASETS LIBRARY=WORK;
			DELETE OPUT&i SAMP&i Oput_Cox&i treatment_count&i control_count&i corr&i
            treatment_prev&i realization&i;
		RUN;QUIT;

%END;
	ODS LISTING;


	%LET ENDTIME=%SYSFUNC(TIME());
	%LET TOTALTIME=%SYSFUNC(ROUND(%SYSEVALF(&ENDTIME-&BEGINTIME),.01));


	%LET ENDTIME=%SYSFUNC(TIME());
	%LET TOTALTIME=%SYSFUNC(ROUND(%SYSEVALF(&ENDTIME-&BEGINTIME),.01));
	%PUT TOTAL TIME FOR MACRO TO RUN (SECONDS) = &TOTALTIME;

%MEND trial;

%trial(NUMSAMP=2000, INDSET=test, HR=1.5, OUTDSET=DONE);

data done;
set done;
if Parameter = 'covariate' then delete;
R_squared = covariate*covariate;
if HRLowerCL < 1.5 < HRUpperCL then coverage = 1;
else coverage = 0;
if HRLowerCL > 1 then prob_lcl_above_1 = 1;
else prob_lcl_above_1  = 0;
run;

ods output Summary=Final;
proc means data=done n mean std nolabels median;
var treatment_count treatment_competing treatment_non_event treatment_time
control_count control_competing control_non_event control_time
R_squared 
Estimate HazardRatio HRLowerCL HRUpperCL coverage StdErr 
prob_lcl_above_1
treatment_Mean;
options nosource nonotes;
run;

data final7;
set final;
little_r = (treatment_Mean_Mean)/(1-treatment_Mean_Mean);
total_events = treatment_count_Mean + control_count_Mean;
crude_RR = (treatment_count_Mean / treatment_time_Mean)/(control_count_Mean/control_time_mean);
little_r_prime = treatment_non_event_Mean / control_non_event_Mean;
little_r_tilde = (little_r + little_r_prime)/2;

SE0 = (SQRT(((little_r + 1)**2)/(total_events*little_r)))/StdErr_Mean;
SE0_adj = (SQRT(((little_r + 1)**2)/(total_events*little_r))/SQRT(1-R_squared_Mean))/StdErr_Mean;

SE1 = (SQRT(((little_r*crude_RR + 1)**2)/(total_events*little_r*crude_RR)))/StdErr_Mean;
SE1_adj = (SQRT(((little_r*crude_RR + 1)**2)/(total_events*little_r*crude_RR))/SQRT(1-R_squared_Mean))/StdErr_Mean;

SE2 = (SQRT(((little_r_tilde*crude_RR + 1)**2)/(total_events*little_r_tilde*crude_RR)))/StdErr_Mean;
SE2_adj = (SQRT(((little_r_tilde*crude_RR + 1)**2)/(total_events*little_r_tilde*crude_RR))/SQRT(1-R_squared_Mean))/StdErr_Mean;

SE3 = (SQRT(1/treatment_count_Mean + 1/control_count_Mean))/StdErr_Mean;
SE3_adj = SQRT((1/treatment_count_Mean + 1/control_count_Mean)/(1-R_squared_Mean))/StdErr_Mean;


SE0_adj_LCL = EXP(Estimate_Mean - 1.96*(SQRT(((little_r + 1)**2)/(total_events*little_r))/SQRT(1-R_squared_Mean)));
SE1_adj_LCL = EXP(Estimate_Mean - 1.96*(SQRT(((little_r*crude_RR + 1)**2)/(total_events*little_r*crude_RR))/SQRT(1-R_squared_Mean)));
SE2_adj_LCL = EXP(Estimate_Mean - 1.96*(SQRT(((little_r_tilde*crude_RR + 1)**2)/(total_events*little_r_tilde*crude_RR))/SQRT(1-R_squared_Mean)));
SE3_adj_LCL = EXP(Estimate_Mean - 1.96*SQRT((1/treatment_count_Mean + 1/control_count_Mean)/(1-R_squared_Mean)));
LCL_sim = HRLowerCL_Mean;

SE0_adj_UCL = EXP(Estimate_Mean + 1.96*(SQRT(((little_r + 1)**2)/(total_events*little_r))/SQRT(1-R_squared_Mean)));
SE1_adj_UCL = EXP(Estimate_Mean + 1.96*(SQRT(((little_r*crude_RR + 1)**2)/(total_events*little_r*crude_RR))/SQRT(1-R_squared_Mean)));
SE2_adj_UCL = EXP(Estimate_Mean + 1.96*(SQRT(((little_r_tilde*crude_RR + 1)**2)/(total_events*little_r_tilde*crude_RR))/SQRT(1-R_squared_Mean)));
SE3_adj_UCL = EXP(Estimate_Mean + 1.96*SQRT((1/treatment_count_Mean + 1/control_count_Mean)/(1-R_squared_Mean)));
UCL_sim = HRUpperCL_Mean;

if Estimate_Mean > 0 then
SE0_adj_power=1-cdf('NORMAL',0,LOG(1.5)-1.96*(SQRT(((little_r + 1)**2)/(total_events*little_r))/SQRT(1-R_squared_Mean)),(SQRT(((little_r + 1)**2)/(total_events*little_r))/SQRT(1-R_squared_Mean)));
else SE0_adj_power=cdf('NORMAL',0,LOG(1.5)+1.96*(SQRT(((little_r + 1)**2)/(total_events*little_r))/SQRT(1-R_squared_Mean)),(SQRT(((little_r + 1)**2)/(total_events*little_r))/SQRT(1-R_squared_Mean)));

if Estimate_Mean > 0 then
SE1_adj_power=1-cdf('NORMAL',0,LOG(1.5)-1.96*(SQRT(((little_r*crude_RR + 1)**2)/(total_events*little_r*crude_RR))/SQRT(1-R_squared_Mean)),(SQRT(((little_r*crude_RR + 1)**2)/(total_events*little_r*crude_RR))/SQRT(1-R_squared_Mean)));
else SE1_adj_power=cdf('NORMAL',0,LOG(1.5)+1.96*(SQRT(((little_r*crude_RR + 1)**2)/(total_events*little_r*crude_RR))/SQRT(1-R_squared_Mean)),(SQRT(((little_r*crude_RR + 1)**2)/(total_events*little_r*crude_RR))/SQRT(1-R_squared_Mean)));

if Estimate_Mean > 0 then
SE2_adj_power=1-cdf('NORMAL',0,LOG(1.5)-1.96*(SQRT(((little_r_tilde*crude_RR + 1)**2)/(total_events*little_r_tilde*crude_RR))/SQRT(1-R_squared_Mean)),(SQRT(((little_r_tilde*crude_RR + 1)**2)/(total_events*little_r_tilde*crude_RR))/SQRT(1-R_squared_Mean)));
else SE2_adj_power=cdf('NORMAL',0,LOG(1.5)+1.96*(SQRT(((little_r_tilde*crude_RR + 1)**2)/(total_events*little_r_tilde*crude_RR))/SQRT(1-R_squared_Mean)),(SQRT(((little_r_tilde*crude_RR + 1)**2)/(total_events*little_r_tilde*crude_RR))/SQRT(1-R_squared_Mean)));

if Estimate_Mean > 0 then
SE3_adj_power=1-cdf('NORMAL',0,LOG(1.5)-1.96*(SQRT((1/treatment_count_Mean + 1/control_count_Mean)/(1-R_squared_Mean))),SQRT((1/treatment_count_Mean + 1/control_count_Mean)/(1-R_squared_Mean)));
else SE3_adj_power=cdf('NORMAL',0,LOG(1.5)+1.96*(SQRT((1/treatment_count_Mean + 1/control_count_Mean)/(1-R_squared_Mean))),SQRT((1/treatment_count_Mean + 1/control_count_Mean)/(1-R_squared_Mean)));

power_sim = prob_lcl_above_1_Mean;
SE_margin = StdErr_StdDev / SQRT(StdErr_N);
Power_margin = SQRT(power_sim*(1-power_sim)/StdErr_N);
options nosource nonotes;
run;

/* SETTING 8 */
ods graphics off;
ods html close;
ods listing;

DATA TEST;
INPUT Subject COUNT;
CARDS;
1 1000
;RUN;

DATA TEST (DROP=subject count);
	SET TEST;
	DO i=1 TO COUNT;
	OUTPUT;
	END;
RUN;

data test (DROP=i);
set test;
Subject = i;
run;

data test;
set test;
if Subject =< 250 then treatment = 1;
else treatment = 0;
run;


%MACRO trial(NUMSAMP=, INDSET=, HR=, OUTDSET=);
	%LET BEGINTIME=%SYSFUNC(TIME());
	DM LOG 'CLEAR';

	PROC DATASETS LIBRARY=WORK;
		DELETE &OUTDSET;
    options nosource nonotes;
	RUN;QUIT;
	PROC DATASETS LIBRARY=WORK;
		DELETE OPUT;
    options nosource nonotes;
	RUN;QUIT;

	ODS LISTING CLOSE;

	%DO i = 1 %TO &NUMSAMP;
data realization&i;
set &indset;
if treatment = 1 then covariate = ranbin(&i,1,0.6);
else covariate = ranbin(&i+10000,1,0.3);

if treatment = 1 AND covariate = 1
then X = ranexp(&i+20000)/(0.12*&HR);
else if treatment = 0 AND covariate = 1
then X = ranexp(&i+30000)/0.12;
else if treatment = 1 AND covariate = 0
then X = ranexp(&i+40000)/(0.06*&HR);
else X = ranexp(&i+50000)/0.06;

C = uniform(&i+60000)*2 + 3;
if treatment = 1 then H = ranexp(&i+70000)/0.05;
else H = ranexp(&i+80000)/0.05;
if X < C AND X < H then Y = 1;
else Y = 0;
T = min(X,C,H);
if H < C AND H < X then Z = 1;
else Z = 0;
if Y = 0 AND Z = 0 then S = 1;
else S = 0;
treat_b = 0.405;
covar_b = 0.693;
w = EXP(treatment*treat_b + covariate*covar_b);
options nosource nonotes;
run;

ods output ParameterEstimates = Oput_Cox&i;
proc phreg data=realization&i;
model T*Y(0)=treatment covariate / risklimits;
options nosource nonotes;
run;

ods output Summary=treatment_count&i;
proc means data=realization&i sum;
var Y Z S T;
where treatment=1;
options nosource nonotes;
run;

data treatment_count&i (drop = Y_sum Z_sum S_sum T_sum);
set treatment_count&i;
treatment_count = Y_sum;
treatment_competing = Z_sum;
treatment_non_event = S_sum;
treatment_time = T_sum;
options nosource nonotes;
run;

ods output Summary=control_count&i;
proc means data=realization&i sum;
var Y Z T S;
where treatment=0;
options nosource nonotes;
run;

data control_count&i (drop = Y_sum Z_sum S_sum T_sum);
set control_count&i;
control_count = Y_sum;
control_competing = Z_sum;
control_non_event = S_sum;
control_time = T_sum;
options nosource nonotes;
run;

ods output PearsonCorr=Corr&i;
proc corr data=realization&i;
var treatment covariate;
weight w;
run;

data corr&i;
set corr&i;
if Variable = 'covariate' then delete;
run;

ods output Summary=treatment_prev&i;
proc means data=realization&i mean;
var treatment;
options nosource nonotes;
run;

data Oput&i;
merge Oput_Cox&i treatment_count&i control_count&i corr&i
treatment_prev&i;
run;

		PROC APPEND BASE=&OUTDSET NEW=OPUT&i FORCE;
		RUN;

		PROC DATASETS LIBRARY=WORK;
			DELETE OPUT&i SAMP&i Oput_Cox&i treatment_count&i control_count&i corr&i
            treatment_prev&i realization&i;
		RUN;QUIT;

%END;
	ODS LISTING;


	%LET ENDTIME=%SYSFUNC(TIME());
	%LET TOTALTIME=%SYSFUNC(ROUND(%SYSEVALF(&ENDTIME-&BEGINTIME),.01));


	%LET ENDTIME=%SYSFUNC(TIME());
	%LET TOTALTIME=%SYSFUNC(ROUND(%SYSEVALF(&ENDTIME-&BEGINTIME),.01));
	%PUT TOTAL TIME FOR MACRO TO RUN (SECONDS) = &TOTALTIME;

%MEND trial;

%trial(NUMSAMP=2000, INDSET=test, HR=1.5, OUTDSET=DONE);

data done;
set done;
if Parameter = 'covariate' then delete;
R_squared = covariate*covariate;
if HRLowerCL < 1.5 < HRUpperCL then coverage = 1;
else coverage = 0;
if HRLowerCL > 1 then prob_lcl_above_1 = 1;
else prob_lcl_above_1  = 0;
run;

ods output Summary=Final;
proc means data=done n mean std nolabels median;
var treatment_count treatment_competing treatment_non_event treatment_time
control_count control_competing control_non_event control_time
R_squared 
Estimate HazardRatio HRLowerCL HRUpperCL coverage StdErr 
prob_lcl_above_1
treatment_Mean;
options nosource nonotes;
run;

data final8;
set final;
little_r = (treatment_Mean_Mean)/(1-treatment_Mean_Mean);
total_events = treatment_count_Mean + control_count_Mean;
crude_RR = (treatment_count_Mean / treatment_time_Mean)/(control_count_Mean/control_time_mean);
little_r_prime = treatment_non_event_Mean / control_non_event_Mean;
little_r_tilde = (little_r + little_r_prime)/2;

SE0 = (SQRT(((little_r + 1)**2)/(total_events*little_r)))/StdErr_Mean;
SE0_adj = (SQRT(((little_r + 1)**2)/(total_events*little_r))/SQRT(1-R_squared_Mean))/StdErr_Mean;

SE1 = (SQRT(((little_r*crude_RR + 1)**2)/(total_events*little_r*crude_RR)))/StdErr_Mean;
SE1_adj = (SQRT(((little_r*crude_RR + 1)**2)/(total_events*little_r*crude_RR))/SQRT(1-R_squared_Mean))/StdErr_Mean;

SE2 = (SQRT(((little_r_tilde*crude_RR + 1)**2)/(total_events*little_r_tilde*crude_RR)))/StdErr_Mean;
SE2_adj = (SQRT(((little_r_tilde*crude_RR + 1)**2)/(total_events*little_r_tilde*crude_RR))/SQRT(1-R_squared_Mean))/StdErr_Mean;

SE3 = (SQRT(1/treatment_count_Mean + 1/control_count_Mean))/StdErr_Mean;
SE3_adj = SQRT((1/treatment_count_Mean + 1/control_count_Mean)/(1-R_squared_Mean))/StdErr_Mean;

SE0_adj_LCL = EXP(Estimate_Mean - 1.96*(SQRT(((little_r + 1)**2)/(total_events*little_r))/SQRT(1-R_squared_Mean)));
SE1_adj_LCL = EXP(Estimate_Mean - 1.96*(SQRT(((little_r*crude_RR + 1)**2)/(total_events*little_r*crude_RR))/SQRT(1-R_squared_Mean)));
SE2_adj_LCL = EXP(Estimate_Mean - 1.96*(SQRT(((little_r_tilde*crude_RR + 1)**2)/(total_events*little_r_tilde*crude_RR))/SQRT(1-R_squared_Mean)));
SE3_adj_LCL = EXP(Estimate_Mean - 1.96*SQRT((1/treatment_count_Mean + 1/control_count_Mean)/(1-R_squared_Mean)));
LCL_sim = HRLowerCL_Mean;

SE0_adj_UCL = EXP(Estimate_Mean + 1.96*(SQRT(((little_r + 1)**2)/(total_events*little_r))/SQRT(1-R_squared_Mean)));
SE1_adj_UCL = EXP(Estimate_Mean + 1.96*(SQRT(((little_r*crude_RR + 1)**2)/(total_events*little_r*crude_RR))/SQRT(1-R_squared_Mean)));
SE2_adj_UCL = EXP(Estimate_Mean + 1.96*(SQRT(((little_r_tilde*crude_RR + 1)**2)/(total_events*little_r_tilde*crude_RR))/SQRT(1-R_squared_Mean)));
SE3_adj_UCL = EXP(Estimate_Mean + 1.96*SQRT((1/treatment_count_Mean + 1/control_count_Mean)/(1-R_squared_Mean)));
UCL_sim = HRUpperCL_Mean;

if Estimate_Mean > 0 then
SE0_adj_power=1-cdf('NORMAL',0,LOG(1.5)-1.96*(SQRT(((little_r + 1)**2)/(total_events*little_r))/SQRT(1-R_squared_Mean)),(SQRT(((little_r + 1)**2)/(total_events*little_r))/SQRT(1-R_squared_Mean)));
else SE0_adj_power=cdf('NORMAL',0,LOG(1.5)+1.96*(SQRT(((little_r + 1)**2)/(total_events*little_r))/SQRT(1-R_squared_Mean)),(SQRT(((little_r + 1)**2)/(total_events*little_r))/SQRT(1-R_squared_Mean)));

if Estimate_Mean > 0 then
SE1_adj_power=1-cdf('NORMAL',0,LOG(1.5)-1.96*(SQRT(((little_r*crude_RR + 1)**2)/(total_events*little_r*crude_RR))/SQRT(1-R_squared_Mean)),(SQRT(((little_r*crude_RR + 1)**2)/(total_events*little_r*crude_RR))/SQRT(1-R_squared_Mean)));
else SE1_adj_power=cdf('NORMAL',0,LOG(1.5)+1.96*(SQRT(((little_r*crude_RR + 1)**2)/(total_events*little_r*crude_RR))/SQRT(1-R_squared_Mean)),(SQRT(((little_r*crude_RR + 1)**2)/(total_events*little_r*crude_RR))/SQRT(1-R_squared_Mean)));

if Estimate_Mean > 0 then
SE2_adj_power=1-cdf('NORMAL',0,LOG(1.5)-1.96*(SQRT(((little_r_tilde*crude_RR + 1)**2)/(total_events*little_r_tilde*crude_RR))/SQRT(1-R_squared_Mean)),(SQRT(((little_r_tilde*crude_RR + 1)**2)/(total_events*little_r_tilde*crude_RR))/SQRT(1-R_squared_Mean)));
else SE2_adj_power=cdf('NORMAL',0,LOG(1.5)+1.96*(SQRT(((little_r_tilde*crude_RR + 1)**2)/(total_events*little_r_tilde*crude_RR))/SQRT(1-R_squared_Mean)),(SQRT(((little_r_tilde*crude_RR + 1)**2)/(total_events*little_r_tilde*crude_RR))/SQRT(1-R_squared_Mean)));

if Estimate_Mean > 0 then
SE3_adj_power=1-cdf('NORMAL',0,LOG(1.5)-1.96*(SQRT((1/treatment_count_Mean + 1/control_count_Mean)/(1-R_squared_Mean))),SQRT((1/treatment_count_Mean + 1/control_count_Mean)/(1-R_squared_Mean)));
else SE3_adj_power=cdf('NORMAL',0,LOG(1.5)+1.96*(SQRT((1/treatment_count_Mean + 1/control_count_Mean)/(1-R_squared_Mean))),SQRT((1/treatment_count_Mean + 1/control_count_Mean)/(1-R_squared_Mean)));

power_sim = prob_lcl_above_1_Mean;
SE_margin = StdErr_StdDev / SQRT(StdErr_N);
Power_margin = SQRT(power_sim*(1-power_sim)/StdErr_N);
options nosource nonotes;
run;

/* SETTING 9 */
ods graphics off;
ods html close;
ods listing;

DATA TEST;
INPUT Subject COUNT;
CARDS;
1 1000
;RUN;

DATA TEST (DROP=subject count);
	SET TEST;
	DO i=1 TO COUNT;
	OUTPUT;
	END;
RUN;

data test (DROP=i);
set test;
Subject = i;
run;

data test;
set test;
if Subject =< 250 then treatment = 1;
else treatment = 0;
run;


%MACRO trial(NUMSAMP=, INDSET=, HR=, OUTDSET=);
	%LET BEGINTIME=%SYSFUNC(TIME());
	DM LOG 'CLEAR';

	PROC DATASETS LIBRARY=WORK;
		DELETE &OUTDSET;
    options nosource nonotes;
	RUN;QUIT;
	PROC DATASETS LIBRARY=WORK;
		DELETE OPUT;
    options nosource nonotes;
	RUN;QUIT;

	ODS LISTING CLOSE;

	%DO i = 1 %TO &NUMSAMP;
data realization&i;
set &indset;
if treatment = 1 then covariate = ranbin(&i,1,0.9);
else covariate = ranbin(&i+10000,1,0.3);

if treatment = 1 AND covariate = 1
then X = ranexp(&i+20000)/(0.12*&HR);
else if treatment = 0 AND covariate = 1
then X = ranexp(&i+30000)/0.12;
else if treatment = 1 AND covariate = 0
then X = ranexp(&i+40000)/(0.06*&HR);
else X = ranexp(&i+50000)/0.06;

C = uniform(&i+60000)*2 + 3;
if treatment = 1 then H = ranexp(&i+70000)/0.05;
else H = ranexp(&i+80000)/0.05;
if X < C AND X < H then Y = 1;
else Y = 0;
T = min(X,C,H);
if H < C AND H < X then Z = 1;
else Z = 0;
if Y = 0 AND Z = 0 then S = 1;
else S = 0;
treat_b = 0.405;
covar_b = 0.693;
w = EXP(treatment*treat_b + covariate*covar_b);
options nosource nonotes;
run;

ods output ParameterEstimates = Oput_Cox&i;
proc phreg data=realization&i;
model T*Y(0)=treatment covariate / risklimits;
options nosource nonotes;
run;

ods output Summary=treatment_count&i;
proc means data=realization&i sum;
var Y Z S T;
where treatment=1;
options nosource nonotes;
run;

data treatment_count&i (drop = Y_sum Z_sum S_sum T_sum);
set treatment_count&i;
treatment_count = Y_sum;
treatment_competing = Z_sum;
treatment_non_event = S_sum;
treatment_time = T_sum;
options nosource nonotes;
run;

ods output Summary=control_count&i;
proc means data=realization&i sum;
var Y Z T S;
where treatment=0;
options nosource nonotes;
run;

data control_count&i (drop = Y_sum Z_sum S_sum T_sum);
set control_count&i;
control_count = Y_sum;
control_competing = Z_sum;
control_non_event = S_sum;
control_time = T_sum;
options nosource nonotes;
run;

ods output PearsonCorr=Corr&i;
proc corr data=realization&i;
var treatment covariate;
weight w;
run;

data corr&i;
set corr&i;
if Variable = 'covariate' then delete;
run;

ods output Summary=treatment_prev&i;
proc means data=realization&i mean;
var treatment;
options nosource nonotes;
run;

data Oput&i;
merge Oput_Cox&i treatment_count&i control_count&i corr&i
treatment_prev&i;
run;

		PROC APPEND BASE=&OUTDSET NEW=OPUT&i FORCE;
		RUN;

		PROC DATASETS LIBRARY=WORK;
			DELETE OPUT&i SAMP&i Oput_Cox&i treatment_count&i control_count&i corr&i
            treatment_prev&i realization&i;
		RUN;QUIT;

%END;
	ODS LISTING;


	%LET ENDTIME=%SYSFUNC(TIME());
	%LET TOTALTIME=%SYSFUNC(ROUND(%SYSEVALF(&ENDTIME-&BEGINTIME),.01));


	%LET ENDTIME=%SYSFUNC(TIME());
	%LET TOTALTIME=%SYSFUNC(ROUND(%SYSEVALF(&ENDTIME-&BEGINTIME),.01));
	%PUT TOTAL TIME FOR MACRO TO RUN (SECONDS) = &TOTALTIME;

%MEND trial;

%trial(NUMSAMP=2000, INDSET=test, HR=1.5, OUTDSET=DONE);

data done;
set done;
if Parameter = 'covariate' then delete;
R_squared = covariate*covariate;
if HRLowerCL < 1.5 < HRUpperCL then coverage = 1;
else coverage = 0;
if HRLowerCL > 1 then prob_lcl_above_1 = 1;
else prob_lcl_above_1  = 0;
run;

ods output Summary=Final;
proc means data=done n mean std nolabels median;
var treatment_count treatment_competing treatment_non_event treatment_time
control_count control_competing control_non_event control_time
R_squared 
Estimate HazardRatio HRLowerCL HRUpperCL coverage StdErr 
prob_lcl_above_1
treatment_Mean;
options nosource nonotes;
run;

data final9;
set final;
little_r = (treatment_Mean_Mean)/(1-treatment_Mean_Mean);
total_events = treatment_count_Mean + control_count_Mean;
crude_RR = (treatment_count_Mean / treatment_time_Mean)/(control_count_Mean/control_time_mean);
little_r_prime = treatment_non_event_Mean / control_non_event_Mean;
little_r_tilde = (little_r + little_r_prime)/2;

SE0 = (SQRT(((little_r + 1)**2)/(total_events*little_r)))/StdErr_Mean;
SE0_adj = (SQRT(((little_r + 1)**2)/(total_events*little_r))/SQRT(1-R_squared_Mean))/StdErr_Mean;

SE1 = (SQRT(((little_r*crude_RR + 1)**2)/(total_events*little_r*crude_RR)))/StdErr_Mean;
SE1_adj = (SQRT(((little_r*crude_RR + 1)**2)/(total_events*little_r*crude_RR))/SQRT(1-R_squared_Mean))/StdErr_Mean;

SE2 = (SQRT(((little_r_tilde*crude_RR + 1)**2)/(total_events*little_r_tilde*crude_RR)))/StdErr_Mean;
SE2_adj = (SQRT(((little_r_tilde*crude_RR + 1)**2)/(total_events*little_r_tilde*crude_RR))/SQRT(1-R_squared_Mean))/StdErr_Mean;

SE3 = (SQRT(1/treatment_count_Mean + 1/control_count_Mean))/StdErr_Mean;
SE3_adj = SQRT((1/treatment_count_Mean + 1/control_count_Mean)/(1-R_squared_Mean))/StdErr_Mean;

SE0_adj_LCL = EXP(Estimate_Mean - 1.96*(SQRT(((little_r + 1)**2)/(total_events*little_r))/SQRT(1-R_squared_Mean)));
SE1_adj_LCL = EXP(Estimate_Mean - 1.96*(SQRT(((little_r*crude_RR + 1)**2)/(total_events*little_r*crude_RR))/SQRT(1-R_squared_Mean)));
SE2_adj_LCL = EXP(Estimate_Mean - 1.96*(SQRT(((little_r_tilde*crude_RR + 1)**2)/(total_events*little_r_tilde*crude_RR))/SQRT(1-R_squared_Mean)));
SE3_adj_LCL = EXP(Estimate_Mean - 1.96*SQRT((1/treatment_count_Mean + 1/control_count_Mean)/(1-R_squared_Mean)));
LCL_sim = HRLowerCL_Mean;

SE0_adj_UCL = EXP(Estimate_Mean + 1.96*(SQRT(((little_r + 1)**2)/(total_events*little_r))/SQRT(1-R_squared_Mean)));
SE1_adj_UCL = EXP(Estimate_Mean + 1.96*(SQRT(((little_r*crude_RR + 1)**2)/(total_events*little_r*crude_RR))/SQRT(1-R_squared_Mean)));
SE2_adj_UCL = EXP(Estimate_Mean + 1.96*(SQRT(((little_r_tilde*crude_RR + 1)**2)/(total_events*little_r_tilde*crude_RR))/SQRT(1-R_squared_Mean)));
SE3_adj_UCL = EXP(Estimate_Mean + 1.96*SQRT((1/treatment_count_Mean + 1/control_count_Mean)/(1-R_squared_Mean)));
UCL_sim = HRUpperCL_Mean;

if Estimate_Mean > 0 then
SE0_adj_power=1-cdf('NORMAL',0,LOG(1.5)-1.96*(SQRT(((little_r + 1)**2)/(total_events*little_r))/SQRT(1-R_squared_Mean)),(SQRT(((little_r + 1)**2)/(total_events*little_r))/SQRT(1-R_squared_Mean)));
else SE0_adj_power=cdf('NORMAL',0,LOG(1.5)+1.96*(SQRT(((little_r + 1)**2)/(total_events*little_r))/SQRT(1-R_squared_Mean)),(SQRT(((little_r + 1)**2)/(total_events*little_r))/SQRT(1-R_squared_Mean)));

if Estimate_Mean > 0 then
SE1_adj_power=1-cdf('NORMAL',0,LOG(1.5)-1.96*(SQRT(((little_r*crude_RR + 1)**2)/(total_events*little_r*crude_RR))/SQRT(1-R_squared_Mean)),(SQRT(((little_r*crude_RR + 1)**2)/(total_events*little_r*crude_RR))/SQRT(1-R_squared_Mean)));
else SE1_adj_power=cdf('NORMAL',0,LOG(1.5)+1.96*(SQRT(((little_r*crude_RR + 1)**2)/(total_events*little_r*crude_RR))/SQRT(1-R_squared_Mean)),(SQRT(((little_r*crude_RR + 1)**2)/(total_events*little_r*crude_RR))/SQRT(1-R_squared_Mean)));

if Estimate_Mean > 0 then
SE2_adj_power=1-cdf('NORMAL',0,LOG(1.5)-1.96*(SQRT(((little_r_tilde*crude_RR + 1)**2)/(total_events*little_r_tilde*crude_RR))/SQRT(1-R_squared_Mean)),(SQRT(((little_r_tilde*crude_RR + 1)**2)/(total_events*little_r_tilde*crude_RR))/SQRT(1-R_squared_Mean)));
else SE2_adj_power=cdf('NORMAL',0,LOG(1.5)+1.96*(SQRT(((little_r_tilde*crude_RR + 1)**2)/(total_events*little_r_tilde*crude_RR))/SQRT(1-R_squared_Mean)),(SQRT(((little_r_tilde*crude_RR + 1)**2)/(total_events*little_r_tilde*crude_RR))/SQRT(1-R_squared_Mean)));

if Estimate_Mean > 0 then
SE3_adj_power=1-cdf('NORMAL',0,LOG(1.5)-1.96*(SQRT((1/treatment_count_Mean + 1/control_count_Mean)/(1-R_squared_Mean))),SQRT((1/treatment_count_Mean + 1/control_count_Mean)/(1-R_squared_Mean)));
else SE3_adj_power=cdf('NORMAL',0,LOG(1.5)+1.96*(SQRT((1/treatment_count_Mean + 1/control_count_Mean)/(1-R_squared_Mean))),SQRT((1/treatment_count_Mean + 1/control_count_Mean)/(1-R_squared_Mean)));

power_sim = prob_lcl_above_1_Mean;
SE_margin = StdErr_StdDev / SQRT(StdErr_N);
Power_margin = SQRT(power_sim*(1-power_sim)/StdErr_N);
options nosource nonotes;
run;

data table1;
set final1 final2 final3
final4 final5 final6
final7 final8 final9;
run;

data table1;
set table1;
LCL_SE_margin = StdErr_Mean/(StdErr_Mean + 1.96*SE_margin);
UCL_SE_margin = StdErr_Mean/(StdErr_Mean - 1.96*SE_margin);
LCL_power = power_sim - 1.96*Power_margin;
UCL_power = power_sim + 1.96*Power_margin;
SE_ratio = StdErr_Mean / Estimate_StdDev;
run;

ods html;
title 'Table 1';
proc print data=table1;
var R_squared_Mean 
treatment_count_Mean treatment_competing_Mean 
control_count_Mean control_competing_Mean
crude_RR 
SE0_adj SE1_adj SE2_adj SE3_adj LCL_SE_margin UCL_SE_margin
SE0_adj_power SE1_adj_power SE2_adj_power SE3_adj_power power_sim 
LCL_power UCL_power
coverage_Mean SE_ratio;
run;


libname lib 'H:\data\Documents\Methods papers 2017\Cox model power';
run;

data lib.table1;
set table1;
run;


